@@ -50,8 +50,7 @@ int ac_stor_wcl::StoreAC(engine * eng)
 	{
 		if (av.size() != 0)
 		{
-			cout << "av is not empty!?!" << endl;
-			exit(EXIT_FAILURE);
+			assertion_failed(__FILE__, __LINE__, "av is not empty.");
 		}
 		
 		atom ** atmtab = eng->GetSetup()->GetAtoms();
@@ -64,8 +63,7 @@ int ac_stor_wcl::StoreAC(engine * eng)
 	{
 		if (av.size() != eng->GetSetup()->GetAtomCount())
 		{
-			cout << "ac_stor_wcl::StoreAC(1) ; bad cset_sz." << endl;
-			exit(EXIT_FAILURE);
+			assertion_failed(__FILE__, __LINE__, "av.size() is bad.");
 		}
 	}
 	
@@ -94,8 +92,7 @@ int ac_stor_wcl::StoreAC(model * mdl, int cset)
 	{
 		if (av.size() != 0)
 		{
-			cout << "av is not empty!?!" << endl;
-			exit(EXIT_FAILURE);
+			assertion_failed(__FILE__, __LINE__, "av is not empty.");
 		}
 		
 		atom ** atmtab = mdl->GetCurrentSetup()->GetAtoms();
@@ -108,8 +105,7 @@ int ac_stor_wcl::StoreAC(model * mdl, int cset)
 	{
 		if (av.size() != mdl->GetCurrentSetup()->GetAtomCount())
 		{
-			cout << "ac_stor_wcl::StoreAC(2) ; bad cset_sz." << endl;
-			exit(EXIT_FAILURE);
+			assertion_failed(__FILE__, __LINE__, "av.size() is bad.");
 		}
 	}
 	
