@@ -20,7 +20,7 @@
 
 #include "custom_app.h"
 
-//#include <ghemical/libghemicaldefine.h>
+#include "local_i18n.h"
 
 #include <stdlib.h>	// the definition for NULL...
 
@@ -97,7 +97,7 @@ bool custom_app::AddGlobalLight(ogl_light * light)
 	{
 		LightAdded(light);
 		project::selected_object = light;
-		cout << "added global light." << endl;
+		cout << _("Added global light.") << endl;
 	}
 	
 	return success;
@@ -111,7 +111,7 @@ bool custom_app::AddLocalLight(ogl_light * light, ogl_camera * cam)
 	{
 		LightAdded(light);
 		project::selected_object = light;
-		cout << "added local light." << endl;
+		cout << _("Added local light.") << endl;
 	}
 	
 	return success;
