@@ -2,8 +2,19 @@
 
 // Copyright (C) 2006 Tommi Hassinen.
 
-// This program is free software; you can redistribute it and/or modify it
-// under the terms of the license (GNU GPL) which comes with this package.
+// This package is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation; either version 2 of the License, or
+// (at your option) any later version.
+
+// This package is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License
+// along with this package; if not, write to the Free Software
+// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 
 /*################################################################################################*/
 
@@ -12,7 +23,7 @@
 /*################################################################################################*/
 
 gpcview_wcl::gpcview_wcl(void) :
-	base_wcl(new ogl_camera(ogl_ol_static(), 1.0))
+	pangofont_wcl(new ogl_camera(ogl_ol_static(), 1.0))
 {
 }
 
@@ -44,6 +55,10 @@ void gpcview_wcl::UpdateWnd(void)
 
 void gpcview_wcl::InitGL(void)
 {
+	// all classes that inherit pangofont_wcl must call ogl_InitPangoFont()!!!
+	// ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
+	
+	ogl_InitPangoFont("courier 12");
 }
 
 void gpcview_wcl::RenderGL(rmode)
