@@ -22,6 +22,8 @@
 
 #include "filetrans.h"
 
+#include "local_i18n.h"
+
 #include <gtk/gtk.h>
 
 #include <sstream>
@@ -36,7 +38,7 @@ gtk_file_import_dialog::gtk_file_import_dialog(gtk_project * p1) :
 	prj = p1;
 	
 	dialog = glade_xml_get_widget(xml, "file_import_dialog");
-	if (dialog == NULL) { cout << "file_import_dialog : glade_xml_get_widget() failed!!!" << endl; return; }
+	if (dialog == NULL) { cout << _("file_import_dialog : glade_xml_get_widget() failed!!!") << endl; return; }
 	
 	// initialize the widgets...
 	
@@ -47,7 +49,7 @@ gtk_file_import_dialog::gtk_file_import_dialog(gtk_project * p1) :
 	GtkWidget * optmenu = glade_xml_get_widget(xml, "optionmenu1");
 	GtkWidget * submenu = gtk_menu_new(); GtkWidget * item;
 	
-	item = gtk_menu_item_new_with_label("Automatic");			// insert item "automatic"...
+	item = gtk_menu_item_new_with_label(_("Automatic"));			// insert item "automatic"...
 	gtk_widget_show(item); gtk_menu_append(GTK_MENU(submenu), item);
 	
 #ifdef ENABLE_OPENBABEL
@@ -128,7 +130,7 @@ void gtk_file_import_dialog::handler_ButtonBrowse(GtkWidget *, gpointer data)
 	// handle the file selection...
 	// ^^^^^^^^^^^^^^^^^^^^^^^^^^^^
 	
-	ref->file_selector = gtk_file_selection_new("Select a Trajectory File.");
+	ref->file_selector = gtk_file_selection_new(_("Select a file to import."));
 	g_signal_connect(GTK_FILE_SELECTION(ref->file_selector)->ok_button, "clicked", G_CALLBACK(handler_FileChooser), data);
 	
 	g_signal_connect_swapped(GTK_FILE_SELECTION(ref->file_selector)->ok_button, "clicked", G_CALLBACK(gtk_widget_destroy), ref->file_selector);
