@@ -20,6 +20,8 @@
 
 #include "gtk_geomopt_dialog.h"
 
+#include "local_i18n.h"
+
 #include <gtk/gtk.h>
 
 #include <sstream>
@@ -34,7 +36,11 @@ gtk_geomopt_dialog::gtk_geomopt_dialog(geomopt_param * p1) :
 	param = p1;
 	
 	dialog = glade_xml_get_widget(xml, "geomopt_dialog");
-	if (dialog == NULL) { cout << "geomopt_dialog : glade_xml_get_widget() failed!!!" << endl; return; }
+	if (dialog == NULL)
+	{
+		cout << _("WARNING : geomopt_dialog : glade_xml_get_widget() failed!!!") << endl;
+		return;
+	}
 	
 	// initialize the widgets...
 	
