@@ -20,8 +20,11 @@
 
 #include "gtk_main.h"
 
+#include "ghemicalconfig.h"
 #include <ghemical/utility.h>
 
+#include "local_i18n.h"
+
 #include <gtk/gtk.h>
 #include <gtk/gtkgl.h>
 //#include <gdk-pixbuf/gdk-pixbuf-loader.h>
@@ -39,8 +42,8 @@ static gchar * opt_i = NULL;
 
 static GOptionEntry option_entries[] =
 {
-	{ "file=filename", 'f', 0, G_OPTION_ARG_STRING, & opt_f, "open a file", NULL },
-	{ "import=filename", 'i', 0, G_OPTION_ARG_STRING, & opt_i, "import a file", NULL },
+	{ "file=filename", 'f', 0, G_OPTION_ARG_STRING, & opt_f, _("open a file"), NULL },
+	{ "import=filename", 'i', 0, G_OPTION_ARG_STRING, & opt_i, _("import a file"), NULL },
 	{ NULL }
 };
 
@@ -48,18 +51,21 @@ int main(int argc, char ** argv)
 {
 	GError * error = NULL;
 	
-	GOptionContext * option_context = g_option_context_new("- a GTK2 molecular modelling program");
+#ifdef ENABLE_NLS
+	setlocale(LC_ALL, "");
+	bindtextdomain(GETTEXT_PACKAGE, LOCALE_DIR);
+	bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
+	textdomain(GETTEXT_PACKAGE);
+#endif	// ENABLE_NLS
+	
+	GOptionContext * option_context = g_option_context_new(_("- a GTK2 molecular modelling program"));
 	g_option_context_add_main_entries(option_context, option_entries, NULL);
 	g_option_context_add_group(option_context, gtk_get_option_group(TRUE));
 	g_option_context_parse(option_context, & argc, & argv, & error);
 	
-	//bindtextdomain (PACKAGE, GNOMELOCALEDIR);
-	//bind_textdomain_codeset (PACKAGE, "UTF-8");
-	//textdomain (PACKAGE);
-	
 #ifdef ENABLE_THREADS
 	
-	//g_thread_init(NULL);						// original...
+	//g_thread_init(NULL);					// original...
 	if (!g_thread_supported()) g_thread_init(NULL);		// robertix 2008-04-25
 	
 	gdk_threads_init();
@@ -71,18 +77,38 @@ int main(int argc, char ** argv)
 	
 	gtk_gl_init(& argc, & argv);
 	
-	gint major; gint minor; gdk_gl_query_version (& major, & minor);
-	g_print ("\nOpenGL extension version - %d.%d\n", major, minor);
+	gint major; gint minor;
+	gdk_gl_query_version (& major, & minor);
+	
+	g_print("\n");
+	g_print(_("OpenGL extension version - %d.%d\n"), major, minor);
 	
 #ifndef WIN32
 	
 	libghemical_init(LIBDATA_PATH);
 	strcpy(project::appdata_path, APPDATA_PATH);
 	
-#else		// WIN32
+#else	// WIN32
 	
-	libghemical_init("c:\\msys\\1.0\\myruntime\\share\\libghemical");
-	strcpy(project::appdata_path, "c:\\msys\\1.0\\myruntime\\share\\ghemical");
+	gchar * modpath = g_win32_get_package_installation_directory_of_module(NULL);
+	
+	//g_print ("modpath = %s\n", modpath);
+	
+	// also see: g_win32_locale_filename_from_utf8()
+	// ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
+	// glib-Windows-Compatibility-Functions.html
+	
+	char tmpstr[256]; char * tmploc;
+	
+	tmploc = g_stpcpy(tmpstr, modpath);
+	tmploc = g_stpcpy(tmploc, "\\share\\libghemical");
+	libghemical_init(tmpstr);
+	
+	tmploc = g_stpcpy(tmpstr, modpath);
+	tmploc = g_stpcpy(tmploc, "\\share\\ghemical");
+	strcpy(project::appdata_path, tmpstr);
+	
+	g_free(modpath);
 	
 #endif	// WIN32
 	
@@ -111,8 +137,8 @@ int main(int argc, char ** argv)
 		
 #else	// ENABLE_OPENBABEL
 		
-		cout << "sorry! file import feature is disabled ; you need to recompile" << endl;
-		cout << "libghemical with --enable-openbabel option in order to fix this." << endl;
+		cout << _("Sorry! The file import feature is disabled ; you need to recompile") << endl;
+		cout << _("libghemical with --enable-openbabel option in order to fix this.") << endl;
 		exit(EXIT_FAILURE);
 		
 #endif	// ENABLE_OPENBABEL
