@@ -20,9 +20,11 @@
 
 #include "gtk_moldyn_dialog.h"
 
+#include "local_i18n.h"
+
 #include <gtk/gtk.h>
 
-#include <cstring>	// required by gcc-4.3
+#include <cstring>
 #include <sstream>
 #include <iostream>
 using namespace std;
@@ -35,7 +37,11 @@ gtk_moldyn_dialog::gtk_moldyn_dialog(moldyn_param * p1) :
 	param = p1;
 	
 	dialog = glade_xml_get_widget(xml, "moldyn_dialog");
-	if (dialog == NULL) { cout << "moldyn_dialog : glade_xml_get_widget() failed!!!" << endl; return; }
+	if (dialog == NULL)
+	{
+		cout << _("WARNING : moldyn_dialog : glade_xml_get_widget() failed!!!") << endl;
+		return;
+	}
 	
 	// initialize the widgets...
 	
@@ -223,7 +229,7 @@ void gtk_moldyn_dialog::handler_ButtonBrowse(GtkWidget *, gpointer data)
 	// handle the file selection...
 	// ^^^^^^^^^^^^^^^^^^^^^^^^^^^^
 	
-	ref->file_selector = gtk_file_selection_new("Select a Trajectory File.");
+	ref->file_selector = gtk_file_selection_new(_("Select a Trajectory File."));
 	g_signal_connect(GTK_FILE_SELECTION(ref->file_selector)->ok_button, "clicked", G_CALLBACK(handler_FileChooser), data);
 	
 	g_signal_connect_swapped(GTK_FILE_SELECTION(ref->file_selector)->ok_button, "clicked", G_CALLBACK(gtk_widget_destroy), ref->file_selector);
