@@ -25,170 +25,172 @@
 
 #include "gtk_simple_dialogs.h"
 
+#include "local_i18n.h"
+
 #include <ghemical/utility.h>
 
 /*################################################################################################*/
 
 GtkActionEntry gtk_oglview_wnd::entries[] =
 {
-	{ "AttachDetachGV", NULL, "Attach/Detach This View", NULL, "Select whether this view is attached or in an independent window", (GCallback) gtk_oglview_wnd::popup_ViewsAttachDetach },
+	{ "AttachDetachGV", NULL, N_("Attach/Detach This View"), NULL, N_("Select whether this view is attached or in an independent window"), (GCallback) gtk_oglview_wnd::popup_ViewsAttachDetach },
 	
-	{ "FileMenu", NULL, "_File" },
+	{ "FileMenu", NULL, N_("File") },
 	// ^^^^^^^^
-	{ "Open", GTK_STOCK_OPEN, "_Open", "<control>O", "Open a file", (GCallback) gtk_app::mainmenu_FileOpen },
+	{ "Open", GTK_STOCK_OPEN, N_("Open"), NULL, N_("Open a file"), (GCallback) gtk_app::mainmenu_FileOpen },
 #ifdef ENABLE_OPENBABEL
-	{ "Import", GTK_STOCK_OPEN, "_Import...", "<control>I", "Import other file formats using OpenBabel", (GCallback) gtk_project::popup_FileImport },
+	{ "Import", GTK_STOCK_OPEN, N_("Import..."), NULL, N_("Import other file formats using libopenbabel"), (GCallback) gtk_project::popup_FileImport },
 #endif	// ENABLE_OPENBABEL
-	{ "SaveAs", GTK_STOCK_SAVE, "_Save as...", "<control>S", "Save a file", (GCallback) gtk_app::mainmenu_FileSaveAs },
+	{ "SaveAs", GTK_STOCK_SAVE, N_("Save as..."), NULL, N_("Save a file"), (GCallback) gtk_app::mainmenu_FileSaveAs },
 #ifdef ENABLE_OPENBABEL
-	{ "Export", GTK_STOCK_SAVE, "_Export", "<control>E", "Export other file formats using OpenBabel", (GCallback) gtk_project::popup_FileExport },
+	{ "Export", GTK_STOCK_SAVE, N_("Export"), NULL, N_("Export other file formats using OpenBabel"), (GCallback) gtk_project::popup_FileExport },
 #endif	// ENABLE_OPENBABEL
-//	{ "ExportGraphics", GTK_STOCK_SAVE, "Export _Graphics", "<control>E", "Export graphics", (GCallback) gtk_project::popup_FileExportGraphics },
-	{ "Close", GTK_STOCK_QUIT, "_Close", "<control>C", "Close the file", (GCallback) gtk_app::mainmenu_FileClose },
+//	{ "ExportGraphics", GTK_STOCK_SAVE, N_("Export Graphics"), NULL, N_("Export graphics"), (GCallback) gtk_project::popup_FileExportGraphics },
+	{ "Close", GTK_STOCK_QUIT, N_("Close"), NULL, N_("Close the file"), (GCallback) gtk_app::mainmenu_FileClose },
 	
-	{ "FileExtraMenu", NULL, "_Extra Tools" },
+	{ "FileExtraMenu", NULL, N_("Extra Tools") },
 	// ^^^^^^^^^^^^^
-	{ "FileExtra1", NULL, "_Import PDB", NULL, "Import a PDB file", (GCallback) gtk_project::popup_FileExtra1 },
-//	{ "FileExtra2", NULL, "_Import ???", NULL, "Import a ??? file", (GCallback) gtk_project::popup_FileExtra2 },
+	{ "FileExtra1", NULL, N_("Import PDB"), NULL, N_("Import a PDB file"), (GCallback) gtk_project::popup_FileExtra1 },
+//	{ "FileExtra2", NULL, N_("Import ???"), NULL, N_("Import a ??? file"), (GCallback) gtk_project::popup_FileExtra2 },
 	
-	{ "SelectMenu", NULL, "_Select" },
+	{ "SelectMenu", NULL, N_("Select") },
 	// ^^^^^^^^^^
-	{ "SelectAll", NULL, "Select _All", NULL, "Select all atoms", (GCallback) gtk_project::popup_SelectAll },
-	{ "SelectNone", NULL, "Select _None", NULL, "Select nothing", (GCallback) gtk_project::popup_SelectNone },
-	{ "InvertSelection", NULL, "_Invert Selection", NULL, "Invert the selection", (GCallback) gtk_project::popup_InvertSelection },
-	{ "HideSelected", NULL, "_Hide Selected", NULL, "Hide all selected atoms", (GCallback) gtk_project::popup_HideSelected },
-	{ "ShowSelected", NULL, "_Show Selected", NULL, "Show all selected atoms", (GCallback) gtk_project::popup_ShowSelected },
-	{ "LockSelected", NULL, "_Lock Selected", NULL, "Lock all selected atoms", (GCallback) gtk_project::popup_LockSelected },
-	{ "UnlockSelected", NULL, "_Unlock Selected", NULL, "Unlock all selected atoms", (GCallback) gtk_project::popup_UnlockSelected },
-	{ "DeleteSelected", NULL, "_Delete Selected", NULL, "Delete all selected atoms", (GCallback) gtk_project::popup_DeleteSelected },
+	{ "SelectAll", NULL, N_("Select All"), NULL, N_("Select all atoms"), (GCallback) gtk_project::popup_SelectAll },
+	{ "SelectNone", NULL, N_("Select None"), NULL, N_("Select nothing"), (GCallback) gtk_project::popup_SelectNone },
+	{ "InvertSelection", NULL, N_("Invert Selection"), NULL, N_("Invert the selection"), (GCallback) gtk_project::popup_InvertSelection },
+	{ "HideSelected", NULL, N_("Hide Selected"), NULL, N_("Hide all selected atoms"), (GCallback) gtk_project::popup_HideSelected },
+	{ "ShowSelected", NULL, N_("Show Selected"), NULL, N_("Show all selected atoms"), (GCallback) gtk_project::popup_ShowSelected },
+	{ "LockSelected", NULL, N_("Lock Selected"), NULL, N_("Lock all selected atoms"), (GCallback) gtk_project::popup_LockSelected },
+	{ "UnlockSelected", NULL, N_("Unlock Selected"), NULL, N_("Unlock all selected atoms"), (GCallback) gtk_project::popup_UnlockSelected },
+	{ "DeleteSelected", NULL, N_("Delete Selected"), NULL, N_("Delete all selected atoms"), (GCallback) gtk_project::popup_DeleteSelected },
 	
-	{ "SelectModeMenu", NULL, "_Selection Mode" },
+	{ "SelectModeMenu", NULL, N_("Selection Mode") },
 	// ^^^^^^^^^^^^^^
 // todo : convert these into toggle items so that the setting from project is show in each of the graphics views...
-	{ "SelectAtoms", NULL, "Select _Atoms", NULL, "Select single atoms", (GCallback) gtk_project::popup_SelectModeAtom },
-	{ "SelectResidues", NULL, "Select _Residues", NULL, "Select residues", (GCallback) gtk_project::popup_SelectModeResidue },
-	{ "SelectChains", NULL, "Select _Chains", NULL, "Select chains", (GCallback) gtk_project::popup_SelectModeChain },
-	{ "SelectMolecules", NULL, "Select _Molecules", NULL, "Select molecules", (GCallback) gtk_project::popup_SelectModeMolecule },
+	{ "SelectAtoms", NULL, N_("Select Atoms"), NULL, N_("Select single atoms"), (GCallback) gtk_project::popup_SelectModeAtom },
+	{ "SelectResidues", NULL, N_("Select Residues"), NULL, N_("Select residues"), (GCallback) gtk_project::popup_SelectModeResidue },
+	{ "SelectChains", NULL, N_("Select Chains"), NULL, N_("Select chains"), (GCallback) gtk_project::popup_SelectModeChain },
+	{ "SelectMolecules", NULL, N_("Select Molecules"), NULL, N_("Select molecules"), (GCallback) gtk_project::popup_SelectModeMolecule },
 	
-	{ "RenderMenu", NULL, "_Render" },
+	{ "RenderMenu", NULL, N_("Render") },
 	// ^^^^^^^^^^
 // todo : convert these into toggle items so that the local setting is show in each of the graphics views...
-	{ "RenderQuickUpdate", NULL, "Quick Update Mode", NULL, "Quick Update Mode switches into Wireframe rendering mode when doing interactive work", (GCallback) gtk_oglview_wnd::popup_RenderQuickUpdate },
+	{ "RenderQuickUpdate", NULL, N_("Quick Update Mode"), NULL, N_("Quick Update Mode switches into Wireframe rendering mode when doing interactive work"), (GCallback) gtk_oglview_wnd::popup_RenderQuickUpdate },
 	
-	{ "RendViewsMenu", NULL, "_Views" },
+	{ "RendViewsMenu", NULL, N_("Views") },
 	// ^^^^^^^^^^^^^
-	{ "RendViewsDeleteView", NULL, "Delete This View", NULL, "Delete this graphics view", (GCallback) gtk_oglview_wnd::popup_ViewsDeleteView },
-	{ "RendViewsPushCRDSet", NULL, "Save a CRD-set (experimental)", NULL, "Save a coordinate set", (GCallback) gtk_oglview_wnd::popup_ViewsPushCRDSet },
-	{ "RendViewsSuperimpose", NULL, "Superimpose CRD-sets (experimental)", NULL, "Superimpose coordinate sets", (GCallback) gtk_oglview_wnd::popup_ViewsSuperimpose },
+	{ "RendViewsDeleteView", NULL, N_("Delete This View"), NULL, N_("Delete this graphics view"), (GCallback) gtk_oglview_wnd::popup_ViewsDeleteView },
+	{ "RendViewsPushCRDSet", NULL, N_("Save a CRD-set (experimental)"), NULL, N_("Save a coordinate set"), (GCallback) gtk_oglview_wnd::popup_ViewsPushCRDSet },
+	{ "RendViewsSuperimpose", NULL, N_("Superimpose CRD-sets (experimental)"), NULL, N_("Superimpose coordinate sets"), (GCallback) gtk_oglview_wnd::popup_ViewsSuperimpose },
 	
-	{ "RendViewsCreateMenu", NULL, "_Create" },
+	{ "RendViewsCreateMenu", NULL, N_("Create") },
 	// ^^^^^^^^^^^^^^^^^^^
-	{ "RendViewsCreateWnd", NULL, "New Window", NULL, "Create a new view using the current camera", (GCallback) gtk_oglview_wnd::popup_ViewsNewWnd },
-	{ "RendViewsCreateCam", NULL, "New Camera", NULL, "Create a new view using a new camera", (GCallback) gtk_oglview_wnd::popup_ViewsNewCam },
-	{ "RendViewsCreateELD", NULL, "Energy-level Diagram", NULL, "Create a new energy-level diagram view", (GCallback) gtk_project::popup_ViewsNewELD },
-	{ "RendViewsCreateSSC", NULL, "Secondary Structure Constraints", NULL, "Create a new secondary structure constraints view", (GCallback) gtk_project::popup_ViewsNewSSC },
+	{ "RendViewsCreateWnd", NULL, N_("New Window"), NULL, N_("Create a new view using the current camera"), (GCallback) gtk_oglview_wnd::popup_ViewsNewWnd },
+	{ "RendViewsCreateCam", NULL, N_("New Camera"), NULL, N_("Create a new view using a new camera"), (GCallback) gtk_oglview_wnd::popup_ViewsNewCam },
+	{ "RendViewsCreateELD", NULL, N_("Energy-level Diagram"), NULL, N_("Create a new energy-level diagram view"), (GCallback) gtk_project::popup_ViewsNewELD },
+	{ "RendViewsCreateSSC", NULL, N_("Secondary Structure Constraints"), NULL, N_("Create a new secondary structure constraints view"), (GCallback) gtk_project::popup_ViewsNewSSC },
 	
-	{ "RendLightsMenu", NULL, "_Lights" },
+	{ "RendLightsMenu", NULL, N_("Lights") },
 	// ^^^^^^^^^^^^^^
-	{ "RendLightsNewLight", NULL, "Create New Light", NULL, "Create a new light object", (GCallback) gtk_oglview_wnd::popup_LightsNewLight },
+	{ "RendLightsNewLight", NULL, N_("Create New Light"), NULL, N_("Create a new light object"), (GCallback) gtk_oglview_wnd::popup_LightsNewLight },
 // todo : convert these into toggle items so that the local setting is show in each of the graphics views...
-	{ "RendLightsEnableLocLights", NULL, "Enable Local Lights", NULL, "Switch on/off the local light objects", (GCallback) gtk_oglview_wnd::popup_LightsSwitchLoc },
-	{ "RendLightsEnableGlobLights", NULL, "Enable Global Lights", NULL, "Switch on/off the global light objects", (GCallback) gtk_oglview_wnd::popup_LightsSwitchGlob },
+	{ "RendLightsEnableLocLights", NULL, N_("Enable Local Lights"), NULL, N_("Switch on/off the local light objects"), (GCallback) gtk_oglview_wnd::popup_LightsSwitchLoc },
+	{ "RendLightsEnableGlobLights", NULL, N_("Enable Global Lights"), NULL, N_("Switch on/off the global light objects"), (GCallback) gtk_oglview_wnd::popup_LightsSwitchGlob },
 	
-	{ "RendRenderMenu", NULL, "_Render Mode" },
+	{ "RendRenderMenu", NULL, N_("Render Mode") },
 	// ^^^^^^^^^^^^^^
 // todo : convert these into toggle items so that the local setting is show in each of the graphics views...
-	{ "RendRenderBallStick", NULL, "Ball & Stick", NULL, "Display atoms and bonds using Ball & Stick mode", (GCallback) gtk_project::popup_RModeBallStick },
-	{ "RendRenderVanDerWaals", NULL, "van der Waals", NULL, "Display atoms and bonds using van der Waals mode", (GCallback) gtk_project::popup_RModeVanDerWaals },
-	{ "RendRenderCylinders", NULL, "Cylinders", NULL, "Display atoms and bonds using Cylinders mode", (GCallback) gtk_project::popup_RModeCylinders },
-	{ "RendRenderWireframe", NULL, "Wireframe", NULL, "Display atoms and bonds using Wireframe mode", (GCallback) gtk_project::popup_RModeWireframe },
-	{ "RendRenderNothing", NULL, "Nothing", NULL, "Do not display atoms and bonds", (GCallback) gtk_project::popup_RModeNothing },
+	{ "RendRenderBallStick", NULL, N_("Ball & Stick"), NULL, N_("Display atoms and bonds using Ball & Stick mode"), (GCallback) gtk_project::popup_RModeBallStick },
+	{ "RendRenderVanDerWaals", NULL, N_("van der Waals"), NULL, N_("Display atoms and bonds using van der Waals mode"), (GCallback) gtk_project::popup_RModeVanDerWaals },
+	{ "RendRenderCylinders", NULL, N_("Cylinders"), NULL, N_("Display atoms and bonds using Cylinders mode"), (GCallback) gtk_project::popup_RModeCylinders },
+	{ "RendRenderWireframe", NULL, N_("Wireframe"), NULL, N_("Display atoms and bonds using Wireframe mode"), (GCallback) gtk_project::popup_RModeWireframe },
+	{ "RendRenderNothing", NULL, N_("Nothing"), NULL, N_("Do not display atoms and bonds"), (GCallback) gtk_project::popup_RModeNothing },
 	
-	{ "RendColorMenu", NULL, "_Color Mode" },
+	{ "RendColorMenu", NULL, N_("Color Mode") },
 	// ^^^^^^^^^^^^^
 // todo : convert these into toggle items so that the local setting is show in each of the graphics views...
-	{ "RendColorElement", NULL, "Element", NULL, "Color atoms and bonds by element", (GCallback) gtk_project::popup_CModeElement },
-	{ "RendColorSecStruct", NULL, "Sec-Struct", NULL, "Color atoms and bonds by secondary-structure state", (GCallback) gtk_project::popup_CModeSecStruct },
-	{ "RendColorHydPhob", NULL, "Hydrophobicity", NULL, "Color atoms and bonds by hydrophobicity (experimental)", (GCallback) gtk_project::popup_CModeHydPhob },
+	{ "RendColorElement", NULL, N_("Element"), NULL, N_("Color atoms and bonds by element"), (GCallback) gtk_project::popup_CModeElement },
+	{ "RendColorSecStruct", NULL, N_("Sec-Struct"), NULL, N_("Color atoms and bonds by secondary-structure state"), (GCallback) gtk_project::popup_CModeSecStruct },
+	{ "RendColorHydPhob", NULL, N_("Hydrophobicity"), NULL, N_("Color atoms and bonds by hydrophobicity (experimental)"), (GCallback) gtk_project::popup_CModeHydPhob },
 	
-	{ "RendLabelMenu", NULL, "_Label Mode" },
+	{ "RendLabelMenu", NULL, N_("Label Mode") },
 	// ^^^^^^^^^^^^^
 // todo : convert these into toggle items so that the local setting is show in each of the graphics views...
-	{ "RendLabelIndex", NULL, "Index", NULL, "Label atoms by atom index", (GCallback) gtk_project::popup_LModeIndex },
-	{ "RendLabelElement", NULL, "Element", NULL, "Label atoms by element", (GCallback) gtk_project::popup_LModeElement },
-	{ "RendLabelFCharge", NULL, "Formal Charge", NULL, "Label atoms by formal charge", (GCallback) gtk_project::popup_LModeFCharge },
-	{ "RendLabelPCharge", NULL, "Partial Charge", NULL, "Label atoms by partial charge", (GCallback) gtk_project::popup_LModePCharge },
-	{ "RendLabelAtomType", NULL, "Atom Type", NULL, "Label atoms by atom type", (GCallback) gtk_project::popup_LModeAtomType },
-	{ "RendLabelBuilderID", NULL, "Builder ID", NULL, "Label atoms by sequence builder ID", (GCallback) gtk_project::popup_LModeBuilderID },
-	{ "RendLabelBondType", NULL, "Bond Type", NULL, "Label bonds by bond type", (GCallback) gtk_project::popup_LModeBondType },
-	{ "RendLabelResidue", NULL, "Residue", NULL, "Label by residue", (GCallback) gtk_project::popup_LModeResidue },
-	{ "RendLabelSecStruct", NULL, "Sec-Struct", NULL, "Label by secondary structure state", (GCallback) gtk_project::popup_LModeSecStruct },
-	{ "RendLabelNothing", NULL, "Nothing", NULL, "Do not show labels", (GCallback) gtk_project::popup_LModeNothing },
+	{ "RendLabelIndex", NULL, N_("Index"), NULL, N_("Label atoms by atom index"), (GCallback) gtk_project::popup_LModeIndex },
+	{ "RendLabelElement", NULL, N_("Element"), NULL, N_("Label atoms by element"), (GCallback) gtk_project::popup_LModeElement },
+	{ "RendLabelFCharge", NULL, N_("Formal Charge"), NULL, N_("Label atoms by formal charge"), (GCallback) gtk_project::popup_LModeFCharge },
+	{ "RendLabelPCharge", NULL, N_("Partial Charge"), NULL, N_("Label atoms by partial charge"), (GCallback) gtk_project::popup_LModePCharge },
+	{ "RendLabelAtomType", NULL, N_("Atom Type"), NULL, N_("Label atoms by atom type"), (GCallback) gtk_project::popup_LModeAtomType },
+	{ "RendLabelBuilderID", NULL, N_("Builder ID"), NULL, N_("Label atoms by sequence builder ID"), (GCallback) gtk_project::popup_LModeBuilderID },
+	{ "RendLabelBondType", NULL, N_("Bond Type"), NULL, N_("Label bonds by bond type"), (GCallback) gtk_project::popup_LModeBondType },
+	{ "RendLabelResidue", NULL, N_("Residue"), NULL, N_("Label by residue"), (GCallback) gtk_project::popup_LModeResidue },
+	{ "RendLabelSecStruct", NULL, N_("Sec-Struct"), NULL, N_("Label by secondary structure state"), (GCallback) gtk_project::popup_LModeSecStruct },
+	{ "RendLabelNothing", NULL, N_("Nothing"), NULL, N_("Do not show labels"), (GCallback) gtk_project::popup_LModeNothing },
 	
-	{ "RendProjectionMenu", NULL, "_Projection" },
+	{ "RendProjectionMenu", NULL, N_("Projection") },
 	// ^^^^^^^^^^^^^^^^^^
 // todo : convert these into toggle items so that the local setting is show in each of the graphics views...
-	{ "RendProjOrthographic", NULL, "Orthographic", NULL, "Use orthographic projection", (GCallback) gtk_oglview_wnd::popup_ProjOrthographic },
-	{ "RendProjPerspective", NULL, "Perspective", NULL, "Use perspective projection", (GCallback) gtk_oglview_wnd::popup_ProjPerspective },
+	{ "RendProjOrthographic", NULL, N_("Orthographic"), NULL, N_("Use orthographic projection"), (GCallback) gtk_oglview_wnd::popup_ProjOrthographic },
+	{ "RendProjPerspective", NULL, N_("Perspective"), NULL, N_("Use perspective projection"), (GCallback) gtk_oglview_wnd::popup_ProjPerspective },
 // todo : convert these into toggle items so that the local setting is show in each of the graphics views...
 // todo : add more color combinations ; red/green red/blue ; any others needed???
-	{ "RendProjSterRedBlue", NULL, "Red-Blue Stereo", NULL, "Use red-blue stereo mode", (GCallback) gtk_oglview_wnd::popup_ProjSterRedBlue },
-	{ "RendProjSterRelaxed", NULL, "Relaxed-Eye Stereo", NULL, "Use relaxed-eye stereo mode", (GCallback) gtk_oglview_wnd::popup_ProjSterRelaxed },
+	{ "RendProjSterRedBlue", NULL, N_("Red-Blue Stereo"), NULL, N_("Use red-blue stereo mode"), (GCallback) gtk_oglview_wnd::popup_ProjSterRedBlue },
+	{ "RendProjSterRelaxed", NULL, N_("Relaxed-Eye Stereo"), NULL, N_("Use relaxed-eye stereo mode"), (GCallback) gtk_oglview_wnd::popup_ProjSterRelaxed },
 	
-	{ "ObjectsMenu", NULL, "_Objects" },
+	{ "ObjectsMenu", NULL, N_("Objects") },
 	// ^^^^^^^^^^^
-	{ "ObjectsRibbon", NULL, "Ribbon", NULL, "Create a Ribbon object for displaying peptides/proteins", (GCallback) gtk_project::popup_ObjRibbon },
-	{ "ObjectsEPlane", NULL, "ESP-plane", NULL, "Create an ESP-plane object", (GCallback) gtk_project::popup_ObjEPlane },
-	{ "ObjectsEVolume", NULL, "volume-rendered ESP", NULL, "Create a volume-rendered ESP object", (GCallback) gtk_project::popup_ObjEVolume },
-	{ "ObjectsESurface", NULL, "ESP-surface", NULL, "Create an ESP-surface object", (GCallback) gtk_project::popup_ObjESurface },
-	{ "ObjectsEVDWSurface", NULL, "ESP-colored vdW-surface", NULL, "Create an ESP-colored vdW-surface object", (GCallback) gtk_project::popup_ObjEVDWSurface },
-	{ "ObjectsEDPlane", NULL, "Electron density plane", NULL, "Create an Electron density plane object", (GCallback) gtk_project::popup_ObjEDPlane },
-	{ "ObjectsEDSurface", NULL, "Electron density surface", NULL, "Create an Electron density surface object", (GCallback) gtk_project::popup_ObjEDSurface },
-	{ "ObjectsMOPlane", NULL, "Molecular orbital plane", NULL, "Create a Molecular orbital plane object", (GCallback) gtk_project::popup_ObjMOPlane },
-	{ "ObjectsMOVolume", NULL, "Molecular orbital volume", NULL, "Create a Molecular orbital volume object", (GCallback) gtk_project::popup_ObjMOVolume },
-	{ "ObjectsMOSurface", NULL, "Molecular orbital surface", NULL, "Create a Molecular orbital surface object", (GCallback) gtk_project::popup_ObjMOSurface },
-	{ "ObjectsMODPlane", NULL, "MO-density plane", NULL, "Create an MO-density plane object", (GCallback) gtk_project::popup_ObjMODPlane },
-	{ "ObjectsMODVolume", NULL, "MO-density volume", NULL, "Create an MO-density volume object", (GCallback) gtk_project::popup_ObjMODVolume },
-	{ "ObjectsMODSurface", NULL, "MO-density surface", NULL, "Create an MO-density surface object", (GCallback) gtk_project::popup_ObjMODSurface },
-	{ "ObjectsDeleteCurrent", NULL, "Delete Current Object", NULL, "Delete the currently selected object", (GCallback) gtk_project::popup_ObjectsDeleteCurrent },
+	{ "ObjectsRibbon", NULL, N_("Ribbon"), NULL, N_("Create a Ribbon object for displaying peptides/proteins"), (GCallback) gtk_project::popup_ObjRibbon },
+	{ "ObjectsEPlane", NULL, N_("ESP-plane"), NULL, N_("Create an ESP-plane object"), (GCallback) gtk_project::popup_ObjEPlane },
+	{ "ObjectsEVolume", NULL, N_("volume-rendered ESP"), NULL, N_("Create a volume-rendered ESP object"), (GCallback) gtk_project::popup_ObjEVolume },
+	{ "ObjectsESurface", NULL, N_("ESP-surface"), NULL, N_("Create an ESP-surface object"), (GCallback) gtk_project::popup_ObjESurface },
+	{ "ObjectsEVDWSurface", NULL, N_("ESP-colored vdW-surface"), NULL, N_("Create an ESP-colored vdW-surface object"), (GCallback) gtk_project::popup_ObjEVDWSurface },
+	{ "ObjectsEDPlane", NULL, N_("Electron density plane"), NULL, N_("Create an Electron density plane object"), (GCallback) gtk_project::popup_ObjEDPlane },
+	{ "ObjectsEDSurface", NULL, N_("Electron density surface"), NULL, N_("Create an Electron density surface object"), (GCallback) gtk_project::popup_ObjEDSurface },
+	{ "ObjectsMOPlane", NULL, N_("Molecular orbital plane"), NULL, N_("Create a Molecular orbital plane object"), (GCallback) gtk_project::popup_ObjMOPlane },
+	{ "ObjectsMOVolume", NULL, N_("Molecular orbital volume"), NULL, N_("Create a Molecular orbital volume object"), (GCallback) gtk_project::popup_ObjMOVolume },
+	{ "ObjectsMOSurface", NULL, N_("Molecular orbital surface"), NULL, N_("Create a Molecular orbital surface object"), (GCallback) gtk_project::popup_ObjMOSurface },
+	{ "ObjectsMODPlane", NULL, N_("MO-density plane"), NULL, N_("Create an MO-density plane object"), (GCallback) gtk_project::popup_ObjMODPlane },
+	{ "ObjectsMODVolume", NULL, N_("MO-density volume"), NULL, N_("Create an MO-density volume object"), (GCallback) gtk_project::popup_ObjMODVolume },
+	{ "ObjectsMODSurface", NULL, N_("MO-density surface"), NULL, N_("Create an MO-density surface object"), (GCallback) gtk_project::popup_ObjMODSurface },
+	{ "ObjectsDeleteCurrent", NULL, N_("Delete Current Object"), NULL, N_("Delete the currently selected object"), (GCallback) gtk_project::popup_ObjectsDeleteCurrent },
 	
-	{ "ComputeMenu", NULL, "_Compute" },
+	{ "ComputeMenu", NULL, N_("Compute") },
 	// ^^^^^^^^^^^
-	{ "CompSetup", NULL, "Setup...", NULL, "Setup or change the comp.chem. method in use", (GCallback) gtk_project::popup_CompSetup },
-	{ "CompEnergy", NULL, "Energy", NULL, "Compute a single-point energy", (GCallback) gtk_project::popup_CompEnergy },
-	{ "CompGeomOpt", NULL, "Geometry Optimization...", NULL, "Do a geometry optimization run", (GCallback) gtk_project::popup_CompGeomOpt },
-	{ "CompMolDyn", NULL, "Molecular Dynamics...", NULL, "Do a molecular dynamics run", (GCallback) gtk_project::popup_CompMolDyn },
-	{ "CompRandomSearch", NULL, "Random Conformational Search...", NULL, "Do a random conformational search", (GCallback) gtk_project::popup_CompRandomSearch },
-	{ "CompSystematicSearch", NULL, "Systematic Conformational Search...", NULL, "Do a random conformational search", (GCallback) gtk_project::popup_CompSystematicSearch },
-	{ "CompMonteCarloSearch", NULL, "Monte Carlo Search...", NULL, "Do a Monte Carlo type conformational search", (GCallback) gtk_project::popup_CompMonteCarloSearch },
-	{ "CompTorEnePlot1D", NULL, "Plot Energy vs. 1 Torsion Angle...", NULL, "...todo...", (GCallback) gtk_project::popup_CompTorsionEnergyPlot1D },
-	{ "CompTorEnePlot2D", NULL, "Plot Energy vs. 2 Torsion Angles...", NULL, "...todo...", (GCallback) gtk_project::popup_CompTorsionEnergyPlot2D },
-	{ "CompPopAnaESP", NULL, "Population Analysis (ESP)", NULL, "...todo...", (GCallback) gtk_project::popup_CompPopAnaElectrostatic },
-	{ "CompTransitionSS", NULL, "Transition State Search...", NULL, "...todo...", (GCallback) gtk_project::popup_CompTransitionStateSearch },
-	{ "CompStationarySS", NULL, "Stationary State Search...", NULL, "...todo...", (GCallback) gtk_project::popup_CompStationaryStateSearch },
-	{ "CompFormula", NULL, "Formula", NULL, "...todo...", (GCallback) gtk_project::popup_CompFormula },
+	{ "CompSetup", NULL, N_("Setup..."), NULL, "Setup or change the comp.chem. method in use", (GCallback) gtk_project::popup_CompSetup },
+	{ "CompEnergy", NULL, N_("Energy"), NULL, "Compute a single-point energy", (GCallback) gtk_project::popup_CompEnergy },
+	{ "CompGeomOpt", NULL, N_("Geometry Optimization..."), NULL, "Do a geometry optimization run", (GCallback) gtk_project::popup_CompGeomOpt },
+	{ "CompMolDyn", NULL, N_("Molecular Dynamics..."), NULL, "Do a molecular dynamics run", (GCallback) gtk_project::popup_CompMolDyn },
+	{ "CompRandomSearch", NULL, N_("Random Conformational Search..."), NULL, "Do a random conformational search", (GCallback) gtk_project::popup_CompRandomSearch },
+	{ "CompSystematicSearch", NULL, N_("Systematic Conformational Search..."), NULL, "Do a random conformational search", (GCallback) gtk_project::popup_CompSystematicSearch },
+	{ "CompMonteCarloSearch", NULL, N_("Monte Carlo Search..."), NULL, "Do a Monte Carlo type conformational search", (GCallback) gtk_project::popup_CompMonteCarloSearch },
+	{ "CompTorEnePlot1D", NULL, N_("Plot Energy vs. 1 Torsion Angle..."), NULL, "...todo...", (GCallback) gtk_project::popup_CompTorsionEnergyPlot1D },
+	{ "CompTorEnePlot2D", NULL, N_("Plot Energy vs. 2 Torsion Angles..."), NULL, "...todo...", (GCallback) gtk_project::popup_CompTorsionEnergyPlot2D },
+	{ "CompPopAnaESP", NULL, N_("Population Analysis (ESP)"), NULL, "...todo...", (GCallback) gtk_project::popup_CompPopAnaElectrostatic },
+	{ "CompTransitionSS", NULL, N_("Transition State Search..."), NULL, "...todo...", (GCallback) gtk_project::popup_CompTransitionStateSearch },
+	{ "CompStationarySS", NULL, N_("Stationary State Search..."), NULL, "...todo...", (GCallback) gtk_project::popup_CompStationaryStateSearch },
+	{ "CompFormula", NULL, N_("Formula"), NULL, "...todo...", (GCallback) gtk_project::popup_CompFormula },
 { "CompUC_SetFormalCharge", NULL, "UnderConstruction ; RS ; Set Formal Charge", NULL, "...todo...", (GCallback) gtk_project::popup_CompSetFormalCharge },
 { "CompUC_CreateRS", NULL, "UnderConstruction ; RS ; make RS", NULL, "...todo...", (GCallback) gtk_project::popup_CompCreateRS },
 { "CompUC_CycleRS", NULL, "UnderConstruction ; RS ; cycle RS", NULL, "...todo...", (GCallback) gtk_project::popup_CompCycleRS },
 	
-	{ "TrajView", NULL, "MD Trajectory Viewer...", NULL, "...todo...", (GCallback) gtk_project::popup_TrajView },
-	{ "SetOrbital", NULL, "Set Current Orbital", NULL, "...todo...", (GCallback) gtk_project::popup_SetOrbital },
+	{ "TrajView", NULL, N_("MD Trajectory Viewer..."), NULL, "...todo...", (GCallback) gtk_project::popup_TrajView },
+	{ "SetOrbital", NULL, N_("Set Current Orbital"), NULL, "...todo...", (GCallback) gtk_project::popup_SetOrbital },
 	
-	{ "BuildMenu", NULL, "_Build" },
+	{ "BuildMenu", NULL, N_("Build") },
 	// ^^^^^^^^^
-	{ "BuildSolvateBox", NULL, "Solvate Box...", NULL, "...todo...", (GCallback) gtk_project::popup_SolvateBox },
-	{ "BuildSolvateSphere", NULL, "Solvate Sphere...", NULL, "...todo...", (GCallback) gtk_project::popup_SolvateSphere },
-	{ "BuildSeqBuildAmino", NULL, "Sequence Builder (amino)...", NULL, "...todo...", (GCallback) gtk_project::popup_BuilderAmino },
-	{ "BuildSeqBuildNucleic", NULL, "Sequence Builder (nucleic)...", NULL, "...todo...", (GCallback) gtk_project::popup_BuilderNucleic },
-	{ "BuildCenter", NULL, "Center", NULL, "...todo...", (GCallback) gtk_project::popup_Center },
-	{ "BuildClear", NULL, "Zap All", NULL, "...todo...", (GCallback) gtk_project::popup_ClearAll },
+	{ "BuildSolvateBox", NULL, N_("Solvate Box..."), NULL, "...todo...", (GCallback) gtk_project::popup_SolvateBox },
+	{ "BuildSolvateSphere", NULL, N_("Solvate Sphere..."), NULL, "...todo...", (GCallback) gtk_project::popup_SolvateSphere },
+	{ "BuildSeqBuildAmino", NULL, N_("Sequence Builder (amino)..."), NULL, "...todo...", (GCallback) gtk_project::popup_BuilderAmino },
+	{ "BuildSeqBuildNucleic", NULL, N_("Sequence Builder (nucleic)..."), NULL, "...todo...", (GCallback) gtk_project::popup_BuilderNucleic },
+	{ "BuildCenter", NULL, N_("Center"), NULL, "...todo...", (GCallback) gtk_project::popup_Center },
+	{ "BuildClear", NULL, N_("Zap All"), NULL, "...todo...", (GCallback) gtk_project::popup_ClearAll },
 	
-	{ "BuildHydrogensMenu", NULL, "_Hydrogens" },
+	{ "BuildHydrogensMenu", NULL, N_("Hydrogens") },
 	// ^^^^^^^^^^^^^^^^^^
-	{ "BuildHydrogensAdd", NULL, "Add", NULL, "...todo...", (GCallback) gtk_project::popup_HAdd },
-	{ "BuildHydrogensRemove", NULL, "Remove", NULL, "...todo...", (GCallback) gtk_project::popup_HRemove },
+	{ "BuildHydrogensAdd", NULL, N_("Add"), NULL, "...todo...", (GCallback) gtk_project::popup_HAdd },
+	{ "BuildHydrogensRemove", NULL, N_("Remove"), NULL, "...todo...", (GCallback) gtk_project::popup_HRemove },
 	
-	{ "EnterCommand", NULL, "Enter a Command...", NULL, "...todo...", (GCallback) gtk_project::popup_EnterCommand },
+	{ "EnterCommand", NULL, N_("Enter a Command..."), NULL, "...todo...", (GCallback) gtk_project::popup_EnterCommand },
 };
 
 const char * gtk_oglview_wnd::ui_description =
@@ -364,6 +366,7 @@ gtk_oglview_wnd::gtk_oglview_wnd(bool det_flag) :
 	gtk_wnd(det_flag)
 {
 	GtkActionGroup * action_group = gtk_action_group_new("ggvActions");
+	gtk_action_group_set_translation_domain(action_group, GETTEXT_PACKAGE);
 	gtk_action_group_add_actions(action_group, entries, G_N_ELEMENTS(entries), GTK_WIDGET(view_widget));
 	
 //	GtkUIManager * ui_manager = gtk_app::GetUIManager();	// does not give us independent menu widgets...
@@ -374,7 +377,7 @@ gtk_oglview_wnd::gtk_oglview_wnd(bool det_flag) :
 	GError * error = NULL;
 	if (!gtk_ui_manager_add_ui_from_string(ui_manager, ui_description, -1, & error))
 	{
-		g_message("Building ggv menu failed : %s", error->message);
+		g_message(_("ERROR : Building popup-menu for gtk_oglview_wnd failed : %s"), error->message);
 		g_error_free(error); exit(EXIT_FAILURE);
 	}
 	
@@ -624,13 +627,13 @@ compiler says superimpose is undeclared???");
 		}
 		
 		f64 rms = si.GetRMS(); sum += rms;
-		cout << "sets 0 <-> " << n1 << " RMS = " << rms << endl;
+		cout << _("sets 0 <-> ") << n1 << _(" RMS = ") << rms << endl;
 		
 		si.Transform();		// modify the coordinates!!!
 	}
 	
 	f64 average = sum / ((f64) custom_app::GetPrj()->GetCRDSetCount() - 1);
-	cout << "average RMS = " << average << endl;
+	cout << _("average RMS = ") << average << endl;
 #endif	// ENABLE_OPENBABEL
 	
 	gtk_app::GetPrjX()->UpdateAllGraphicsViews();
