@@ -20,6 +20,8 @@
 
 #include "gtk_progress_dialog.h"
 
+#include "local_i18n.h"
+
 #include <gtk/gtk.h>
 
 #include <sstream>
@@ -32,7 +34,11 @@ gtk_progress_dialog::gtk_progress_dialog(const char * jobname, bool show_pbar, i
 	gtk_glade_dialog("glade/gtk_progress_dialog.glade")
 {
 	dialog = glade_xml_get_widget(xml, "progress_dialog");
-	if (dialog == NULL) { cout << "progress_dialog : glade_xml_get_widget() failed!!!" << endl; return; }
+	if (dialog == NULL)
+	{
+		cout << _("WARNING : progress_dialog : glade_xml_get_widget() failed!!!") << endl;
+		return;
+	}
 	
 	cancel = false;
 	
