@@ -54,6 +54,8 @@
 #include "gtk_setup_dialog.h"
 #include "gtk_progress_dialog.h"
 
+#include "local_i18n.h"
+
 #include <glade/glade.h>
 
 #include <sstream>
@@ -76,25 +78,25 @@ void gtk_project::DoSafeStart(void)
 // pointer obtained before it is actually used anywhere. 20070816 TH
 	
 	AddGraphicsClient(NULL, false);
-	PrintToLog("A new project created.\n");
+	PrintToLog(_("A new project created.\n"));
 }
 
 gtk_project::~gtk_project(void)
 {
-	if (pd != NULL) cout << "MEM-LEAK pd" << endl;
+	if (pd != NULL) cout << "DEBUG : MEM-LEAK pd" << endl;
 }
 
 oglview_wcl * gtk_project::GetClient(GtkWidget * widget)
 {
 	gtk_wnd * wnd = gtk_wnd::iv_Find(widget);
-	if (wnd == NULL) cout << "gtk_project::GetClient() failed!" << endl;
+	if (wnd == NULL) cout << "DEBUG : gtk_project::GetClient() failed!" << endl;
 	else
 	{
 		base_wcl * wcl1 = wnd->GetClient();
-		if (wcl1 == NULL) cout << "NULL wcl1" << endl;
+		if (wcl1 == NULL) cout << "DEBUG : NULL wcl1" << endl;
 		
 		oglview_wcl * wcl2 = dynamic_cast<oglview_wcl *>(wcl1);
-		if (wcl2 == NULL) cout << "NULL wcl2" << endl;
+		if (wcl2 == NULL) cout << "DEBUG : NULL wcl2" << endl;
 		
 		return wcl2;
 	}
@@ -168,7 +170,7 @@ void gtk_project::start_job_GeomOpt(jobinfo_GeomOpt * ji)
 	if (ji->show_dialog)
 	{
 		new gtk_geomopt_dialog(& ji->go);	// the object will call delete itself...
-		cout << "now returning from gtk_project::GeomOptGetParam()." << endl;
+		cout << "DEBUG : now returning from gtk_project::GeomOptGetParam()." << endl;
 		
 		// the above dialog is (AND IT MUST BE) a modal one; we will return
 		// from the function only after the dialog is closed.
@@ -179,7 +181,7 @@ void gtk_project::start_job_GeomOpt(jobinfo_GeomOpt * ji)
 #ifdef ENABLE_THREADS
 	
 	GThread * t = g_thread_create(process_job_GeomOpt, (gpointer) ji, FALSE, NULL);
-	if (t == NULL) ErrorMessage("Thread creation failed : GeomOpt");
+	if (t == NULL) ErrorMessage(_("Thread creation failed : GeomOpt"));
 	
 #else	// ENABLE_THREADS
 	
@@ -194,7 +196,7 @@ gpointer gtk_project::process_job_GeomOpt(gpointer p)
 	jobinfo_GeomOpt * ji = (jobinfo_GeomOpt *) p;
 	
 	ji->prj->ThreadLock();
-	ji->prj->CreateProgressDialog("Geometry Optimization", true, 1, 20);
+	ji->prj->CreateProgressDialog(_("Geometry Optimization"), true, 1, 20);
 	ji->prj->ThreadUnlock();
 	
 #ifdef ENABLE_THREADS
@@ -218,7 +220,7 @@ void gtk_project::start_job_MolDyn(jobinfo_MolDyn * ji)
 	if (ji->show_dialog)
 	{
 		new gtk_moldyn_dialog(& ji->md);		// the object will call delete itself...
-		cout << "now returning from gtk_project::MolDynGetParam()." << endl;
+		cout << "DEBUG : now returning from gtk_project::MolDynGetParam()." << endl;
 		
 		// the above dialog is (AND IT MUST BE) a modal one; we will return
 		// from the function only after the dialog is closed.
@@ -229,7 +231,7 @@ void gtk_project::start_job_MolDyn(jobinfo_MolDyn * ji)
 #ifdef ENABLE_THREADS
 	
 	GThread * t = g_thread_create(process_job_MolDyn, (gpointer) ji, FALSE, NULL);
-	if (t == NULL) ErrorMessage("Thread creation failed : MolDyn");
+	if (t == NULL) ErrorMessage(_("Thread creation failed : MolDyn"));
 	
 #else	// ENABLE_THREADS
 	
@@ -244,7 +246,7 @@ gpointer gtk_project::process_job_MolDyn(gpointer p)
 	jobinfo_MolDyn * ji = (jobinfo_MolDyn *) p;
 	
 	ji->prj->ThreadLock();
-	ji->prj->CreateProgressDialog("Molecular Dynamics", true, NOT_DEFINED, NOT_DEFINED);
+	ji->prj->CreateProgressDialog(_("Molecular Dynamics"), true, NOT_DEFINED, NOT_DEFINED);
 	ji->prj->ThreadUnlock();
 
 #ifdef ENABLE_THREADS
@@ -268,7 +270,7 @@ void gtk_project::start_job_RandomSearch(jobinfo_RandomSearch * ji)
 #ifdef ENABLE_THREADS
 	
 	GThread * t = g_thread_create(process_job_RandomSearch, (gpointer) ji, FALSE, NULL);
-	if (t == NULL) ErrorMessage("Thread creation failed : RandomSearch");
+	if (t == NULL) ErrorMessage(_("Thread creation failed : RandomSearch"));
 	
 #else	// ENABLE_THREADS
 	
@@ -283,7 +285,7 @@ gpointer gtk_project::process_job_RandomSearch(gpointer p)
 	jobinfo_RandomSearch * ji = (jobinfo_RandomSearch *) p;
 	
 	ji->prj->ThreadLock();
-	ji->prj->CreateProgressDialog("Random Search", true, NOT_DEFINED, NOT_DEFINED);
+	ji->prj->CreateProgressDialog(_("Random Search"), true, NOT_DEFINED, NOT_DEFINED);
 	ji->prj->ThreadUnlock();
 	
 #ifdef ENABLE_THREADS
@@ -333,8 +335,7 @@ void gtk_project::DestroyGraphicsWnd(base_wnd * wB)
 	
 	if (!wX)
 	{
-		cout << "gtk_project::DestroyGraphicsWnd() : bad cast." << endl;
-		exit(EXIT_FAILURE);
+		assertion_failed(__FILE__, __LINE__, "bad wnd!");
 	}
 	else
 	{
@@ -419,8 +420,7 @@ void gtk_project::DestroyPlottingWnd(base_wnd * wB)
 	
 	if (!wX)
 	{
-		cout << "gtk_project::DestroyPlottingWnd() : bad cast." << endl;
-		exit(EXIT_FAILURE);
+		assertion_failed(__FILE__, __LINE__, "bad wnd!");
 	}
 	else
 	{
@@ -504,7 +504,7 @@ void gtk_project::popup_FileExtra2(GtkWidget *, gpointer data)
 	
 	if (prj)
 	{
-		prj->Message("not implemented...");
+		prj->Message("this is not yet implemented...");
 	}
 }
 
@@ -560,25 +560,25 @@ void gtk_project::popup_DeleteSelected(GtkWidget *, gpointer data)
 void gtk_project::popup_SelectModeAtom(GtkWidget *, gpointer data)
 {
 	custom_app::current_select_mode = custom_app::smAtom;
-cout << "selection mode = atm" << endl;
+cout << "DEBUG : selection mode = atm" << endl;
 }
 
 void gtk_project::popup_SelectModeResidue(GtkWidget *, gpointer data)
 {
 	custom_app::current_select_mode = custom_app::smResidue;
-cout << "selection mode = res" << endl;
+cout << "DEBUG : selection mode = res" << endl;
 }
 
 void gtk_project::popup_SelectModeChain(GtkWidget *, gpointer data)
 {
 	custom_app::current_select_mode = custom_app::smChain;
-cout << "selection mode = chn" << endl;
+cout << "DEBUG : selection mode = chn" << endl;
 }
 
 void gtk_project::popup_SelectModeMolecule(GtkWidget *, gpointer data)
 {
 	custom_app::current_select_mode = custom_app::smMolecule;
-cout << "selection mode = mol" << endl;
+cout << "DEBUG : selection mode = mol" << endl;
 }
 
 void gtk_project::popup_ViewsNewELD(GtkWidget *, gpointer data)
@@ -773,7 +773,7 @@ void gtk_project::popup_ObjEPlane(GtkWidget *, gpointer data)
 	{
 		if (!prj->GetCurrentSetup()->GetCurrentEngine())
 		{
-			prj->Message("Please calculate energy first!");
+			prj->Message(_("Please calculate energy first!"));
 		}
 		else
 		{
@@ -791,7 +791,7 @@ void gtk_project::popup_ObjEVolume(GtkWidget *, gpointer data)
 	{
 		if (!prj->GetCurrentSetup()->GetCurrentEngine())
 		{
-			prj->Message("Please calculate energy first!");
+			prj->Message(_("Please calculate energy first!"));
 		}
 		else
 		{
@@ -809,7 +809,7 @@ void gtk_project::popup_ObjESurface(GtkWidget *, gpointer data)
 	{
 		if (!prj->GetCurrentSetup()->GetCurrentEngine())
 		{
-			prj->Message("Please calculate energy first!");
+			prj->Message(_("Please calculate energy first!"));
 		}
 		else
 		{
@@ -827,7 +827,7 @@ void gtk_project::popup_ObjEVDWSurface(GtkWidget *, gpointer data)
 	{
 		if (!prj->GetCurrentSetup()->GetCurrentEngine())
 		{
-			prj->Message("Please calculate energy first!");
+			prj->Message(_("Please calculate energy first!"));
 		}
 		else
 		{
@@ -845,7 +845,7 @@ void gtk_project::popup_ObjEDPlane(GtkWidget *, gpointer data)
 	{
 		if (!prj->GetCurrentSetup()->GetCurrentEngine())
 		{
-			prj->Message("Please calculate energy first!");
+			prj->Message(_("Please calculate energy first!"));
 		}
 		else
 		{
@@ -863,7 +863,7 @@ void gtk_project::popup_ObjEDSurface(GtkWidget *, gpointer data)
 	{
 		if (!prj->GetCurrentSetup()->GetCurrentEngine())
 		{
-			prj->Message("Please calculate energy first!");
+			prj->Message(_("Please calculate energy first!"));
 		}
 		else
 		{
@@ -881,7 +881,7 @@ void gtk_project::popup_ObjMOPlane(GtkWidget *, gpointer data)
 	{
 		if (!prj->GetCurrentSetup()->GetCurrentEngine())
 		{
-			prj->Message("Please calculate energy first!");
+			prj->Message(_("Please calculate energy first!"));
 		}
 		else
 		{
@@ -899,7 +899,7 @@ void gtk_project::popup_ObjMOVolume(GtkWidget *, gpointer data)
 	{
 		if (!prj->GetCurrentSetup()->GetCurrentEngine())
 		{
-			prj->Message("Please calculate energy first!");
+			prj->Message(_("Please calculate energy first!"));
 		}
 		else
 		{
@@ -917,7 +917,7 @@ void gtk_project::popup_ObjMOSurface(GtkWidget *, gpointer data)
 	{
 		if (!prj->GetCurrentSetup()->GetCurrentEngine())
 		{
-			prj->Message("Please calculate energy first!");
+			prj->Message(_("Please calculate energy first!"));
 		}
 		else
 		{
@@ -935,7 +935,7 @@ void gtk_project::popup_ObjMODPlane(GtkWidget *, gpointer data)
 	{
 		if (!prj->GetCurrentSetup()->GetCurrentEngine())
 		{
-			prj->Message("Please calculate energy first!");
+			prj->Message(_("Please calculate energy first!"));
 		}
 		else
 		{
@@ -953,7 +953,7 @@ void gtk_project::popup_ObjMODVolume(GtkWidget *, gpointer data)
 	{
 		if (!prj->GetCurrentSetup()->GetCurrentEngine())
 		{
-			prj->Message("Please calculate energy first!");
+			prj->Message(_("Please calculate energy first!"));
 		}
 		else
 		{
@@ -971,7 +971,7 @@ void gtk_project::popup_ObjMODSurface(GtkWidget *, gpointer data)
 	{
 		if (!prj->GetCurrentSetup()->GetCurrentEngine())
 		{
-			prj->Message("Please calculate energy first!");
+			prj->Message(_("Please calculate energy first!"));
 		}
 		else
 		{
@@ -1072,7 +1072,7 @@ void gtk_project::popup_CompTorsionEnergyPlot1D(GtkWidget *, gpointer data)
 	gtk_project * prj = gtk_app::GetPrjX();
 	if (prj)
 	{
-prj->Message("PLEASE NOTE!\nThe command string, which is displayed in the next dialog, is incomplete.\nYou should replace the letters A-D with atom indices that define the torsion.\n\nALSO NOTE: structure refinement is always done using molecular mechanics (optsteps).");
+prj->Message(_("PLEASE NOTE!\nThe command string, which is displayed in the next dialog, is incomplete.\nYou should replace the letters A-D with atom indices that define the torsion.\n\nALSO NOTE: structure refinement is always done using molecular mechanics (optsteps)."));
 		
 		static const char command[] = "make_plot1 A B C D 36 0.0 360.0 250";
 		new gtk_command_dialog(prj, oglwcl, command);
@@ -1085,7 +1085,7 @@ void gtk_project::popup_CompTorsionEnergyPlot2D(GtkWidget *, gpointer data)
 	gtk_project * prj = gtk_app::GetPrjX();
 	if (prj)
 	{
-prj->Message("PLEASE NOTE!\nThe command string, which is displayed in the next dialog, is incomplete.\nYou should replace the letters A-D and I-L with atom indices that define the torsions.\n\nALSO NOTE: structure refinement is always done using molecular mechanics (optsteps).");
+prj->Message(_("PLEASE NOTE!\nThe command string, which is displayed in the next dialog, is incomplete.\nYou should replace the letters A-D and I-L with atom indices that define the torsions.\n\nALSO NOTE: structure refinement is always done using molecular mechanics (optsteps)."));
 		
 		static const char command[] = "make_plot2 A B C D 36 0.0 360.0 I J K L 36 0.0 360.0 250";
 		new gtk_command_dialog(prj, oglwcl, command);
@@ -1159,7 +1159,7 @@ void gtk_project::popup_CompCycleRS(GtkWidget *, gpointer data)	// todo : this i
 	//	prj->GetRS()->CycleStructures();
 		prj->UpdateAllGraphicsViews();
 	}
-	else cout << "ERROR" << endl;
+	else cout << _("ERROR") << endl;
 }
 
 void gtk_project::popup_TrajView(GtkWidget *, gpointer data)
@@ -1170,7 +1170,7 @@ void gtk_project::popup_TrajView(GtkWidget *, gpointer data)
 		// will call delete itself...
 		if (prj) new gtk_trajfile_dialog(prj);
 	}
-	else prj->ErrorMessage("Trajectory already open?!?!?!");
+	else prj->ErrorMessage(_("Trajectory file already open?"));
 }
 
 void gtk_project::popup_SetOrbital(GtkWidget *, gpointer data)
@@ -1179,7 +1179,7 @@ void gtk_project::popup_SetOrbital(GtkWidget *, gpointer data)
 	gtk_project * prj = gtk_app::GetPrjX();
 	if (prj)
 	{
-		prj->Message("PLEASE NOTE!\nThe command string, which is displayed in the next dialog, is incomplete.\nYou should replace the letter X with the orbital index that will become the current orbital.");
+		prj->Message(_("PLEASE NOTE!\nThe command string, which is displayed in the next dialog, is incomplete.\nYou should replace the letter X with the orbital index that will become the current orbital."));
 		
 		static const char command[] = "set_current_orbital X";
 		new gtk_command_dialog(prj, oglwcl, command);
@@ -1234,7 +1234,7 @@ void gtk_project::popup_BuilderAmino(GtkWidget *, gpointer data)
 	gtk_project * prj = gtk_app::GetPrjX();
 	if (prj)
 	{
-prj->Message("PLEASE NOTE!\nThe command string, which is displayed in the next dialog, is incomplete.\nYou should replace the default sequence AAA with the sequence to be built.");
+prj->Message(_("PLEASE NOTE!\nThe command string, which is displayed in the next dialog, is incomplete.\nYou should replace the default sequence AAA with the sequence to be built."));
 		
 		static const char command[] = "build_amino AAA";
 		new gtk_command_dialog(prj, oglwcl, command);
@@ -1247,7 +1247,7 @@ void gtk_project::popup_BuilderNucleic(GtkWidget *, gpointer data)
 	gtk_project * prj = gtk_app::GetPrjX();
 	if (prj)
 	{
-prj->Message("PLEASE NOTE!\nThe command string, which is displayed in the next dialog, is incomplete.\nYou should replace the default sequence AGTCaguc with the sequence to be built.");
+prj->Message(_("PLEASE NOTE!\nThe command string, which is displayed in the next dialog, is incomplete.\nYou should replace the default sequence AGTCaguc with the sequence to be built."));
 		
 		static const char command[] = "build_nucleic AGTCaguc";
 		new gtk_command_dialog(prj, oglwcl, command);
@@ -1284,7 +1284,7 @@ void gtk_project::popup_Center(GtkWidget *, gpointer data)
 void gtk_project::popup_ClearAll(GtkWidget *, gpointer data)
 {
 	gtk_project * prj = gtk_app::GetPrjX();
-	if (prj && base_app::GetAppB()->Question("Are you sure you want to clear everything?"))
+	if (prj && base_app::GetAppB()->Question(_("Are you sure you want to clear everything?")))
 	{
 		prj->ClearModel();
 		prj->UpdateAllGraphicsViews();
