@@ -2,8 +2,19 @@
 
 // Copyright (C) 1998 Tommi Hassinen.
 
-// This program is free software; you can redistribute it and/or modify it
-// under the terms of the license (GNU GPL) which comes with this package.
+// This package is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation; either version 2 of the License, or
+// (at your option) any later version.
+
+// This package is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License
+// along with this package; if not, write to the Free Software
+// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 
 /*################################################################################################*/
 
@@ -49,11 +60,18 @@ class gtk_project : public project
 	
 	static oglview_wcl * GetClient(GtkWidget *);
 	
+#ifdef ENABLE_THREADS
+	
 	void ThreadLock(void);			// virtual
 	void ThreadUnlock(void);		// virtual
-	bool SetProgress(double, double*);	// virtual
 	
-#ifdef ENABLE_THREADS
+#else	// ENABLE_THREADS
+	
+	void NoThreadsIterate(void);		// virtual
+	
+#endif	// ENABLE_THREADS
+	
+	bool SetProgress(double, double*);	// virtual
 	
 	protected:
 	
@@ -64,11 +82,6 @@ class gtk_project : public project
 	void CreateProgressDialog(const char *, bool, int, int);	// virtual
 	void DestroyProgressDialog(void);				// virtual
 	
-#endif	// ENABLE_THREADS
-	
-	void GeomOptGetParam(geomopt_param &);		// virtual
-	void MolDynGetParam(moldyn_param &);		// virtual
-	
 // the GUI threading model is explained here:
 // ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
 // the "main thread" of the program handles gtk_main() loop and callbacks.
@@ -76,6 +89,12 @@ class gtk_project : public project
 // operations, if the program is compiled with ENABLE_THREADS set. therefore all
 // operations in the process_job_XXX() methods below must be made thread-safe
 // in the "gdk_threads" sense. THIS IS STILL EXPERIMENTAL STUFF!!!
+
+// the GUI non-threaded operatios is like this:
+// ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
+// gtk_main_iteration() is called from libghemical level in order to keep the
+// GUI responding ; so this is something like "windows-95"-multitasking stuff...
+// but that's OK since this is a fool-proof solution and responsive enough...
 	
 	void start_job_GeomOpt(jobinfo_GeomOpt *);		// virtual
 	static gpointer process_job_GeomOpt(gpointer);
@@ -111,10 +130,9 @@ class gtk_project : public project
 	
 	static void popup_FileImport(GtkWidget *, gpointer);
 	static void popup_FileExport(GtkWidget *, gpointer);
-	static void popup_FileExportGraphic(GtkWidget *, gpointer);
-	static void popup_FileSaveAs(GtkWidget *, gpointer);
+	static void popup_FileExportGraphics(GtkWidget *, gpointer);
 	static void popup_FileExtra1(GtkWidget *, gpointer);
-	static void popup_FileExtra2(GtkWidget *, gpointer);
+	static void popup_FileExtra2(GtkWidget *, gpointer);	// this is just a stub for a new "extra"-item...
 	
 	static void popup_SelectAll(GtkWidget *, gpointer);
 	static void popup_SelectNone(GtkWidget *, gpointer);
