@@ -23,12 +23,14 @@
 #include "rcpview_wcl.h"
 #include "gtk_app.h"
 
+#include "local_i18n.h"
+
 /*################################################################################################*/
 
 GtkActionEntry gtk_rcpview_wnd::entries[] =
 {
-	{ "AttachDetachRCP", NULL, "Attach/Detach This View", NULL, "Select whether this view is attached or in an independent window", (GCallback) gtk_rcpview_wnd::popup_AttachDetach },
-	{ "DeleteViewRCP", NULL, "Delete View", NULL, "Delete this view", (GCallback) gtk_rcpview_wnd::popup_DeleteView }
+	{ "AttachDetachRCP", NULL, N_("Attach/Detach This View"), NULL, N_("Select whether this view is attached or in an independent window"), (GCallback) gtk_rcpview_wnd::popup_AttachDetach },
+	{ "DeleteViewRCP", NULL, N_("Delete View"), NULL, N_("Delete this view"), (GCallback) gtk_rcpview_wnd::popup_DeleteView }
 };
 
 const char * gtk_rcpview_wnd::ui_description =
@@ -44,6 +46,7 @@ gtk_rcpview_wnd::gtk_rcpview_wnd(bool det_flag) :
 	gtk_wnd(det_flag)
 {
 	GtkActionGroup * action_group = gtk_action_group_new("grcpvActions");
+	gtk_action_group_set_translation_domain(action_group, GETTEXT_PACKAGE);
 	gtk_action_group_add_actions(action_group, entries, G_N_ELEMENTS(entries), GTK_WIDGET(view_widget));
 	
 	gtk_ui_manager_insert_action_group(gtk_app::GetUIManager(), action_group, 0);
@@ -51,7 +54,7 @@ gtk_rcpview_wnd::gtk_rcpview_wnd(bool det_flag) :
 	GError * error = NULL;
 	if (!gtk_ui_manager_add_ui_from_string(gtk_app::GetUIManager(), ui_description, -1, & error))
 	{
-		g_message("Building grcpv menu failed : %s", error->message);
+		g_message(_("ERROR : Building popup-menu for gtk_rcpview_wnd failed : %s"), error->message);
 		g_error_free(error); exit(EXIT_FAILURE);
 	}
 	
