@@ -20,6 +20,8 @@
 
 #include "gtk_setup_dialog.h"
 
+#include "local_i18n.h"
+
 #include <ghemical/engine.h>
 
 #include <ghemical/eng1_qm.h>
@@ -42,7 +44,11 @@ gtk_setup_dialog::gtk_setup_dialog(gtk_project * p1) :
 	prj = p1;
 	
 	dialog = glade_xml_get_widget(xml, "setup_dialog");
-	if (dialog == NULL) { cout << "setup_dialog : glade_xml_get_widget() failed!!!" << endl; return; }
+	if (dialog == NULL)
+	{
+		cout << _("WARNING : setup_dialog : glade_xml_get_widget() failed!!!") << endl;
+		return;
+	}
 	
 	// initialize the widgets...
 	// initialize the widgets...
@@ -202,8 +208,7 @@ gtk_setup_dialog::gtk_setup_dialog(gtk_project * p1) :
 	}
 	else
 	{
-		prj->ErrorMessage("BUG: Bad cast was detected at setup_dialog ctor.\nThe program will terminate.");
-		exit(EXIT_FAILURE);
+		assertion_failed(__FILE__, __LINE__, "setup class unknown.");
 	}
 	
 	// connect the handlers...
@@ -309,8 +314,7 @@ void gtk_setup_dialog::handler_ButtonOK(GtkWidget *, gpointer data)
 			break;
 			
 			default:
-			cout << "callEXIT : cannot set SFmode!" << endl;
-			exit(EXIT_FAILURE);
+			assertion_failed(__FILE__, __LINE__, "cannot set SFmode!");
 		}
 		
 	//delete ref->prj->current_setup;					// get rid of the old setup...
@@ -344,16 +348,15 @@ void gtk_setup_dialog::handler_ButtonOK(GtkWidget *, gpointer data)
 	}
 	else
 	{
-		ref->prj->ErrorMessage("BUG: Invalid current page at setup_dialog::handler_ButtonOK().");
-		exit(EXIT_FAILURE);
+		assertion_failed(__FILE__, __LINE__, "invalid current page.");
 	}
 	
 	// report the new settings to log...
 	// ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
 	
 	ostringstream str1;
-	str1 << "Changed the Setup for calculations ";
-	str1 << "(setup = " << ref->prj->GetCurrentSetup()->GetClassName_lg();
+	str1 << _("Changed the Setup for calculations ");
+	str1 << _("(setup = ") << ref->prj->GetCurrentSetup()->GetClassName_lg();
 	
 	if (current_page == 2)
 	{
@@ -365,12 +368,11 @@ void gtk_setup_dialog::handler_ButtonOK(GtkWidget *, gpointer data)
 			case setup1_sf::modeP3:		str1 << "P3"; break;
 			
 			default:
-			cout << "callEXIT : cannot report SFmode!" << endl;
-			exit(EXIT_FAILURE);
+			assertion_failed(__FILE__, __LINE__, "cannot report SFmode!");
 		}
 	}
 	
-	str1 << ", engine = " << ref->prj->GetCurrentSetup()->GetEngineName(ref->prj->GetCurrentSetup()->GetCurrEngIndex());
+	str1 << _(", engine = ") << ref->prj->GetCurrentSetup()->GetEngineName(ref->prj->GetCurrentSetup()->GetCurrEngIndex());
 	str1 << ")." << endl << ends;
 	
 	ref->prj->PrintToLog(str1.str().c_str());
