@@ -27,8 +27,10 @@
 
 #include "gtk_trajview_dialog.h"
 
-#include <cstring>	// required by gcc-4.3
-using namespace std;	// required by gcc-4.3
+#include "local_i18n.h"
+
+#include <cstring>
+using namespace std;
 
 /*################################################################################################*/
 
@@ -44,7 +46,7 @@ gtk_element_dialog::gtk_element_dialog(void)
 	
 	gtk_window_set_modal(GTK_WINDOW(dialog), TRUE);		// request a modal window.
 	
-	gtk_window_set_title(GTK_WINDOW(dialog), "Set Current Element");
+	gtk_window_set_title(GTK_WINDOW(dialog), _("Set Current Element"));
 	gtk_window_set_position(GTK_WINDOW(dialog), GTK_WIN_POS_CENTER);
 	
 	GtkWidget * table = gtk_table_new(21, 38, TRUE);
@@ -108,7 +110,7 @@ gtk_element_dialog::~gtk_element_dialog(void)
 void gtk_element_dialog::SignalHandler(GtkWidget *, int signal)
 {
 	element::current_element = element(signal);
-	cout << "current element is now " << element::current_element.GetSymbol() << endl;	// which prj???
+	cout << _("Current element is now ") << element::current_element.GetSymbol() << "." << endl;	// which prj???
 	
 	gtk_widget_destroy(dialog);
 	delete current_object;		// the object was created with new!!!
@@ -128,7 +130,7 @@ gtk_bondtype_dialog::gtk_bondtype_dialog(void)
 	
 	gtk_window_set_modal(GTK_WINDOW(dialog), TRUE);		// request a modal window.
 	
-	gtk_window_set_title(GTK_WINDOW(dialog), "Set Current Bondtype");
+	gtk_window_set_title(GTK_WINDOW(dialog), _("Set Current Bondtype"));
 	gtk_window_set_position(GTK_WINDOW(dialog), GTK_WIN_POS_CENTER);
 	
 	GtkWidget * table = gtk_table_new((2 + 4 + 1), 6, TRUE);
@@ -179,7 +181,7 @@ gtk_bondtype_dialog::~gtk_bondtype_dialog(void)
 void gtk_bondtype_dialog::SignalHandler(GtkWidget *, int signal)
 {
 	bondtype::current_bondtype = bondtype((char) signal);
-	cout << "current bondtype is now " << bondtype::current_bondtype.GetString() << endl;	// which prj???
+	cout << _("Current bondtype is now ") << bondtype::current_bondtype.GetString() << "." << endl;		// which prj???
 	
 	gtk_widget_destroy(dialog);
 	delete current_object;		// the object was created with new!!!
@@ -324,8 +326,7 @@ bool gtk_file_save_dialog::OkEvent(const char * filename)
 {
 	if (prj == NULL)
 	{
-		prj->ErrorMessage("BUG: file_save_dialog::OkEvent() failed.");
-		exit(EXIT_FAILURE);
+		assertion_failed(__FILE__, __LINE__, "prj == NULL");
 	}
 	
 	// should check to see if file already exists...
@@ -371,8 +372,7 @@ bool gtk_file_save_graphics_dialog::OkEvent(const char * filename)
 {
 	if (prj == NULL)
 	{
-		prj->ErrorMessage("BUG: file_save_graphics_dialog::OkEvent() failed.");
-		exit(EXIT_FAILURE);
+		assertion_failed(__FILE__, __LINE__, "prj == NULL");
 	}
 	
 	// write graphics event
@@ -403,7 +403,8 @@ gtk_trajfile_dialog::~gtk_trajfile_dialog(void)
 
 bool gtk_trajfile_dialog::OkEvent(const char * filename)
 {
-	cout << "trying to open \"" << filename << "\"." << endl;
+	cout << "DEBUG : trying to open \"" << filename << "\"." << endl;
+	
 	prj->OpenTrajectory(filename);
 // check if there were problems with OpenTrajectory()?!?!?!
 // check if there were problems with OpenTrajectory()?!?!?!
@@ -445,7 +446,7 @@ bool gtk_importpdb_dialog::OkEvent(const char * filename)
 {
 	if (prj != NULL)
 	{
-		prj->WarningMessage("This alternative PDB reader is designed to remove any gaps that might\nexist in the structure data. Therefore the sequence might be altered!");
+		prj->WarningMessage(_("This alternative PDB reader is designed to remove any gaps that might\nexist in the structure data. Therefore the sequence might be altered!"));
 		
 		prj->ParseProjectFileNameAndPath(filename);
 		
@@ -478,7 +479,7 @@ gtk_command_dialog::gtk_command_dialog(gtk_project * p1, oglview_wcl * p2, const
 	dialog = gtk_dialog_new();
 	gtk_window_set_modal(GTK_WINDOW(dialog), TRUE);		// request a modal window.
 	
-	gtk_window_set_title(GTK_WINDOW(dialog), "Command Interpreter");
+	gtk_window_set_title(GTK_WINDOW(dialog), _("Command Interpreter"));
 	gtk_window_set_position(GTK_WINDOW(dialog), GTK_WIN_POS_CENTER);
 	gtk_window_set_default_size(GTK_WINDOW(dialog), 400, 50);
 	
@@ -499,10 +500,10 @@ gtk_command_dialog::gtk_command_dialog(gtk_project * p1, oglview_wcl * p2, const
 	
 	gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, TRUE, 0);
 	
-	GtkWidget * button_ok = gtk_button_new_with_label("OK");
+	GtkWidget * button_ok = gtk_button_new_with_label(_("Execute"));
 	gtk_signal_connect(GTK_OBJECT(button_ok), "clicked", GTK_SIGNAL_FUNC(OkButtonHandler), this);
 	
-	GtkWidget * button_cancel = gtk_button_new_with_label("Cancel");
+	GtkWidget * button_cancel = gtk_button_new_with_label(_("Cancel"));
 	gtk_signal_connect(GTK_OBJECT(button_cancel), "clicked", GTK_SIGNAL_FUNC(CancelButtonHandler), this);
 	
 	gtk_box_pack_start(GTK_BOX(hbox), button_ok, FALSE, TRUE, 0);
