@@ -21,6 +21,7 @@
 #include "gtk_stereo_dialog.h"
 
 #include "gtk_app.h"
+#include "local_i18n.h"
 
 /*################################################################################################*/
 
@@ -31,7 +32,11 @@ gtk_stereo_dialog::gtk_stereo_dialog(gtk_oglview_wnd * p1) :
 	scaling = 1.0;
 	
 	dialog = glade_xml_get_widget(xml, "stereo_dialog");
-	if (dialog == NULL) { cout << "stereo_dialog : glade_xml_get_widget() failed!!!" << endl; return; }
+	if (dialog == NULL)
+	{
+		cout << _("WARNING : stereo_dialog : glade_xml_get_widget() failed!!!") << endl;
+		return;
+	}
 	
 	// connect the handlers...
 	
@@ -61,7 +66,7 @@ void gtk_stereo_dialog::CloseDialog(void)
 void gtk_stereo_dialog::handler_Destroy(GtkWidget *, gpointer data)
 {
 	gtk_stereo_dialog * ref = (gtk_stereo_dialog *) data;
-	cout << "handler_Destroy() : ref = " << ref << endl;
+	cout << "DEBUG : handler_Destroy() : ref = " << ref << endl;
 	
 	// tell others that we are closed!!!
 	// ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
@@ -75,7 +80,7 @@ void gtk_stereo_dialog::handler_SepChanged(GtkWidget * range, gpointer data)
 	gtk_stereo_dialog * ref = (gtk_stereo_dialog *) data;
 	
 	const float value = gtk_range_get_value(GTK_RANGE(range)) * ref->scaling;
-	//cout << "gtk_stereo_dialog::handler_SepChanged() " << value << endl;
+	//cout << "DEBUG : gtk_stereo_dialog::handler_SepChanged() " << value << endl;
 	
 	ref->wnd->GetClient()->GetCam()->relaxed_separation = value;
 	gtk_app::GetPrjX()->UpdateGraphicsViews(ref->wnd->GetClient()->GetCam());
@@ -86,7 +91,7 @@ void gtk_stereo_dialog::handler_DispChanged(GtkWidget * range, gpointer data)
 	gtk_stereo_dialog * ref = (gtk_stereo_dialog *) data;
 	
 	const float value = gtk_range_get_value(GTK_RANGE(range)) * ref->scaling;
-	//cout << "gtk_stereo_dialog::handler_DispChanged() " << value << endl;
+	//cout << "DEBUG : gtk_stereo_dialog::handler_DispChanged() " << value << endl;
 	
 	ref->wnd->GetClient()->GetCam()->stereo_displacement = value;
 	gtk_app::GetPrjX()->UpdateGraphicsViews(ref->wnd->GetClient()->GetCam());
