@@ -20,6 +20,8 @@
 
 #include "gtk_trajview_dialog.h"
 
+#include "local_i18n.h"
+
 #include <sstream>
 #include <iostream>
 using namespace std;
@@ -32,7 +34,11 @@ gtk_trajview_dialog::gtk_trajview_dialog(gtk_project * p1) :
 	prj = p1;
 	
 	dialog = glade_xml_get_widget(xml, "trajview_dialog");
-	if (dialog == NULL) { cout << "trajview_dialog : glade_xml_get_widget() failed!!!" << endl; return; }
+	if (dialog == NULL)
+	{
+		cout << _("WARNING : trajview_dialog : glade_xml_get_widget() failed!!!") << endl;
+		return;
+	}
 	
 	// connect the handlers...
 	
@@ -73,7 +79,7 @@ void gtk_trajview_dialog::handler_ButtonBegin(GtkWidget *, gpointer data)
 	ref->prj->ReadTrajectoryFrame();
 	
 	ostringstream str1;
-	str1 << "frame = " << ref->prj->GetCurrentFrame() << endl << ends;
+	str1 << _("frame = ") << ref->prj->GetCurrentFrame() << endl << ends;
 	ref->prj->PrintToLog(str1.str().c_str());
 	
 	ref->prj->UpdateAllGraphicsViews(true);
@@ -93,7 +99,7 @@ void gtk_trajview_dialog::handler_ButtonPrev(GtkWidget *, gpointer data)
 	ref->prj->ReadTrajectoryFrame();
 	
 	ostringstream str1;
-	str1 << "frame = " << ref->prj->GetCurrentFrame() << endl << ends;
+	str1 << _("frame = ") << ref->prj->GetCurrentFrame() << endl << ends;
 	ref->prj->PrintToLog(str1.str().c_str());
 	
 	ref->prj->UpdateAllGraphicsViews(true);
@@ -127,7 +133,7 @@ void gtk_trajview_dialog::handler_ButtonNext(GtkWidget *, gpointer data)
 	ref->prj->ReadTrajectoryFrame();
 	
 	ostringstream str1;
-	str1 << "frame = " << ref->prj->GetCurrentFrame() << endl << ends;
+	str1 << _("frame = ") << ref->prj->GetCurrentFrame() << endl << ends;
 	ref->prj->PrintToLog(str1.str().c_str());
 	
 	ref->prj->UpdateAllGraphicsViews(true);
@@ -142,7 +148,7 @@ void gtk_trajview_dialog::handler_ButtonEnd(GtkWidget *, gpointer data)
 	ref->prj->ReadTrajectoryFrame();
 	
 	ostringstream str1;
-	str1 << "frame = " << ref->prj->GetCurrentFrame() << endl << ends;
+	str1 << _("frame = ") << ref->prj->GetCurrentFrame() << endl << ends;
 	ref->prj->PrintToLog(str1.str().c_str());
 	
 	ref->prj->UpdateAllGraphicsViews(true);
