@@ -21,6 +21,7 @@
 #include "gtk_wnd.h"
 
 #include "gtk_app.h"
+#include "local_i18n.h"
 
 #include <GL/gl.h>
 #include <GL/glu.h>
@@ -49,20 +50,20 @@ gtk_wnd::gtk_wnd(bool det_flag) :
 	
 	if (glconfig == NULL)
 	{
-		g_print("*** Cannot find the double-buffered visual.\n");
-		g_print("*** Trying single-buffered visual.\n");
+		g_print(_("*** Cannot find the double-buffered visual.\n"));
+		g_print(_("*** Trying single-buffered visual.\n"));
 		
 		mode = (GdkGLConfigMode) (GDK_GL_MODE_RGB | GDK_GL_MODE_DEPTH);
 		glconfig = gdk_gl_config_new_by_mode(mode);	// try a single-buffered visual...
 		
 		if (glconfig == NULL)
 		{
-			g_print("*** No appropriate OpenGL-capable visual found.\n");
+			g_print(_("*** No appropriate OpenGL-capable visual found.\n"));
 			exit(EXIT_FAILURE);
 		}
 	}
 	
-	g_print ("\nOpenGL visual configurations :\n\n");
+	g_print (_("\nOpenGL visual configurations :\n\n"));
 	g_print ("gdk_gl_config_is_rgba (glconfig) = %s\n", gdk_gl_config_is_rgba (glconfig) ? "TRUE" : "FALSE");
 	g_print ("gdk_gl_config_is_double_buffered (glconfig) = %s\n", gdk_gl_config_is_double_buffered (glconfig) ? "TRUE" : "FALSE");
 	g_print ("gdk_gl_config_is_stereo (glconfig) = %s\n", gdk_gl_config_is_stereo (glconfig) ? "TRUE" : "FALSE");
@@ -141,8 +142,7 @@ gtk_wnd::~gtk_wnd(void)
 	}
 	else
 	{
-		cout << "ERROR : gtk_wnd dtor ; removal from iv failed!" << endl;
-		exit(EXIT_FAILURE);
+		assertion_failed(__FILE__, __LINE__, "removal from iv failed!");
 	}
 }
 
@@ -158,13 +158,13 @@ gtk_wnd * gtk_wnd::iv_Find(GtkWidget * vw)
 
 void gtk_wnd::RealizeHandler(GtkWidget * widget, gpointer)
 {
-//cout << "gtk_wnd::RealizeHandler()" << endl;
+//cout << "DEBUG : gtk_wnd::RealizeHandler()" << endl;
 ////////////////////////////////////////////////////////////
 	
 	// realize signal will occur when the widget is created.
 	
 	gtk_wnd * w = iv_Find(widget);
-	if (w == NULL) cout << "gtk_wnd::RealizeHandler() : iv_Find() failed!" << endl;
+	if (w == NULL) cout << "DEBUG : gtk_wnd::RealizeHandler() : iv_Find() failed!" << endl;
 	else
 	{
 		w->SetRealized();
@@ -194,7 +194,7 @@ void gtk_wnd::RealizeHandler(GtkWidget * widget, gpointer)
 			
 			if (!gdk_gl_drawable_make_current(gldrawable, glcontext))
 			{
-				g_print("gtk_wnd::RealizeHandler() : gdk_gl_drawable_make_current() failed.\n");
+				g_print("DEBUG : gtk_wnd::RealizeHandler() : gdk_gl_drawable_make_current() failed.\n");
 			}
 			else
 			{
@@ -215,7 +215,7 @@ void gtk_wnd::RealizeHandler(GtkWidget * widget, gpointer)
 
 gint gtk_wnd::ExposeHandler(GtkWidget * widget, GdkEventExpose * event)
 {
-//cout << "gtk_wnd::ExposeHandler()" << endl;
+//cout << "DEBUG : gtk_wnd::ExposeHandler()" << endl;
 ////////////////////////////////////////////////////////////
 	
 	// expose_event will occur when the window should be re-drawn.
@@ -226,19 +226,17 @@ gint gtk_wnd::ExposeHandler(GtkWidget * widget, GdkEventExpose * event)
 	if (event->count > 0) return TRUE;	// draw only last expose.
 	
 	gtk_wnd * w = iv_Find(widget);
-	if (w == NULL) cout << "gtk_wnd::ButtonHandler() : iv_Find() failed!" << endl;
+	if (w == NULL) cout << "DEBUG : gtk_wnd::ButtonHandler() : iv_Find() failed!" << endl;
 	else
 	{
 		if (!w->GetRealized())
 		{
-			cout << "ExposeHandler ; NOT REALIZED!!!" << endl;
-			exit(EXIT_FAILURE);
+			assertion_failed(__FILE__, __LINE__, "NOT REALIZED!");
 		}
 		
 		if (!w->GetInitialized())
 		{
-			cout << "ExposeHandler ; NOT INITIALIZED!!!" << endl;
-			exit(EXIT_FAILURE);
+			assertion_failed(__FILE__, __LINE__, "NOT INITIALIZED!");
 		}
 		
 		base_wcl * wcl = w->GetClient();
@@ -249,7 +247,7 @@ gint gtk_wnd::ExposeHandler(GtkWidget * widget, GdkEventExpose * event)
 			
 			if (!gdk_gl_drawable_make_current(gldrawable, glcontext))
 			{
-				g_print("gtk_wnd::ExposeHandler() : gdk_gl_drawable_make_current() failed.\n");
+				g_print("DEBUG : gtk_wnd::ExposeHandler() : gdk_gl_drawable_make_current() failed.\n");
 			}
 			else
 			{
@@ -279,19 +277,18 @@ int button_event_lost_counter = 0;
 
 gint gtk_wnd::ButtonHandler(GtkWidget * widget, GdkEventButton * eb)
 {
-//cout << "gtk_wnd::ButtonHandler()" << endl;
+//cout << "DEBUG : gtk_wnd::ButtonHandler()" << endl;
 ////////////////////////////////////////////////////////////
 	
 	// button_press/release_event(s) are triggered by mouse events.
 	
 	gtk_wnd * w = iv_Find(widget);
-	if (w == NULL) cout << "gtk_wnd::ButtonHandler() : iv_Find() failed!" << endl;
+	if (w == NULL) cout << "DEBUG : gtk_wnd::ButtonHandler() : iv_Find() failed!" << endl;
 	else
 	{
 		if (!w->GetRealized())
 		{
-			cout << "ButtonHandler ; NOT REALIZED!!!" << endl;
-			exit(EXIT_FAILURE);
+			assertion_failed(__FILE__, __LINE__, "NOT REALIZED!");
 		}
 		
 		mouseinfo::mi_button tmpb;
@@ -343,7 +340,7 @@ gint gtk_wnd::ButtonHandler(GtkWidget * widget, GdkEventButton * eb)
 				
 				mouseinfo::state = mouseinfo::sDown;
 				
-			//	cout << "button_event_D " << mouseinfo::button << " " << mouseinfo::state << endl;
+			//	cout << "DEBUG : button_event_D " << mouseinfo::button << " " << mouseinfo::state << endl;
 				w->GetClient()->ButtonEvent((i32s) eb->x, (i32s) eb->y);
 				
 				// this is for exceptions, see below...
@@ -359,7 +356,7 @@ gint gtk_wnd::ButtonHandler(GtkWidget * widget, GdkEventButton * eb)
 			
 			mouseinfo::state = mouseinfo::sUp;
 			
-		//	cout << "button_event_U " << mouseinfo::button << " " << mouseinfo::state << endl;
+		//	cout << "DEBUG : button_event_U " << mouseinfo::button << " " << mouseinfo::state << endl;
 			w->GetClient()->ButtonEvent((i32s) eb->x, (i32s) eb->y);
 			
 			mouseinfo::button = mouseinfo::bNone;
@@ -371,7 +368,7 @@ gint gtk_wnd::ButtonHandler(GtkWidget * widget, GdkEventButton * eb)
 
 gint gtk_wnd::MotionNotifyHandler(GtkWidget * widget, GdkEventMotion * event)
 {
-//cout << "gtk_wnd::MotionNotifyHandler()" << endl;
+//cout << "DEBUG : gtk_wnd::MotionNotifyHandler()" << endl;
 ////////////////////////////////////////////////////////////
 	
 	// mouse movements will trigger the events here...
@@ -394,14 +391,14 @@ gint gtk_wnd::MotionNotifyHandler(GtkWidget * widget, GdkEventMotion * event)
 		if (button_event_lost_counter > 1)
 		{
 			gtk_wnd * w = iv_Find(widget);
-			if (w == NULL) cout << "gtk_wnd::MotionNotifyHandler() : iv_Find() failed!" << endl;
+			if (w == NULL) cout << "DEBUG : gtk_wnd::MotionNotifyHandler() : iv_Find() failed!" << endl;
 			else
 			{
-				cout << "WARNING ; a mouse-button-up event was lost!" << endl;
+				cout << "DEBUG : WARNING ; a mouse-button-up event was lost!" << endl;
 				
 				mouseinfo::state = mouseinfo::sUp;
 				
-			//	cout << "button_event_U " << mouseinfo::button << " " << mouseinfo::state << endl;
+			//	cout << "DEBUG : button_event_U " << mouseinfo::button << " " << mouseinfo::state << endl;
 				w->GetClient()->ButtonEvent((i32s) x, (i32s) y);
 				
 				mouseinfo::button = mouseinfo::bNone;
@@ -415,10 +412,10 @@ gint gtk_wnd::MotionNotifyHandler(GtkWidget * widget, GdkEventMotion * event)
 	if (mouseinfo::button != mouseinfo::bNone)
 	{
 		gtk_wnd * w = iv_Find(widget);
-		if (w == NULL) cout << "gtk_wnd::MotionNotifyHandler() : iv_Find() failed!" << endl;
+		if (w == NULL) cout << "DEBUG : gtk_wnd::MotionNotifyHandler() : iv_Find() failed!" << endl;
 		else
 		{
-		//	cout << "motion_event " << mouseinfo::button << " " << mouseinfo::state << endl;
+		//	cout << "DEBUG : motion_event " << mouseinfo::button << " " << mouseinfo::state << endl;
 			w->GetClient()->MotionEvent(x, y);
 		}
 	}
@@ -428,7 +425,7 @@ gint gtk_wnd::MotionNotifyHandler(GtkWidget * widget, GdkEventMotion * event)
 
 gint gtk_wnd::ConfigureHandler(GtkWidget * widget, GdkEventConfigure *)
 {
-//cout << "gtk_wnd::ConfigureHandler()" << endl;
+//cout << "DEBUG : gtk_wnd::ConfigureHandler()" << endl;
 ////////////////////////////////////////////////////////////
 	
 	// configure_event will occur at each window size change,
@@ -440,7 +437,7 @@ gint gtk_wnd::ConfigureHandler(GtkWidget * widget, GdkEventConfigure *)
 		w->SetWidth(widget->allocation.width);
 		w->SetHeight(widget->allocation.height);
 	}
-	else cout << "iv_Find() failed at gtk_wnd::ConfigureHandler()." << endl;
+	else cout << "DEBUG : iv_Find() failed at gtk_wnd::ConfigureHandler()." << endl;
 	
 	// the screen is NOT always properly updated after a configure-event.
 	// sometimes it gets rendered 100% fine, but sometimes only partially
@@ -491,7 +488,7 @@ void gtk_wnd::RequestUpdate(bool directly)
 
 void gtk_wnd::RequestResize(int, int)
 {
-cout << "gtk_wnd::RequestResize()" << endl;
+cout << "DEBUG : gtk_wnd::RequestResize() not yet implemented!" << endl;
 }
 
 bool gtk_wnd::SetCurrent(void)
@@ -501,7 +498,7 @@ bool gtk_wnd::SetCurrent(void)
 	
 	if (!gdk_gl_drawable_make_current(gldrawable, glcontext))
 	{
-		g_print("gtk_wnd::SetCurrent() : gdk_gl_drawable_make_current() failed.\n");
+		g_print("DEBUG : gtk_wnd::SetCurrent() : gdk_gl_drawable_make_current() failed.\n");
 		return false;
 	}
 	else
@@ -514,8 +511,7 @@ void gtk_wnd::TitleChanged(void)
 {
 	if (GetClient() == NULL)
 	{
-		cout << "ERROR : gtk_wnd::TitleChanged() called for an unlinked window." << endl;
-		exit(EXIT_FAILURE);
+		assertion_failed(__FILE__, __LINE__, "wnd is unlinked.");
 	}
 	
 	if (detached != NULL)
