@@ -26,7 +26,7 @@
 
 #include <GL/gl.h>
 
-#include <cstring>	// required by gcc-4.3
+#include <cstring>
 #include <fstream>
 #include <sstream>
 using namespace std;
