@@ -45,14 +45,12 @@ ogl_ribbon::ogl_ribbon(project * p1, color_mode * p9, i32s p2, i32s order) :
 	
 	if (ci_vector[chn].GetType() != chn_info::amino_acid)
 	{
-		prj->ErrorMessage("BUG: The chain type is not correct (\"amino_acid\").\nThe program will terminate.");
-		exit(EXIT_FAILURE);
+		assertion_failed(__FILE__, __LINE__, "chn type != AA");
 	}
 	
 	if (ci_vector[chn].GetLength() < 3)
 	{
-		prj->ErrorMessage("BUG: Tried to create a ribbon with less than 3 residues.\nThe program will terminate.");
-		exit(EXIT_FAILURE);
+		assertion_failed(__FILE__, __LINE__, "chn length < 3");
 	}
 	
 	const char * tmp_sss = ci_vector[chn].GetSecStrStates();
@@ -73,8 +71,7 @@ ogl_ribbon::ogl_ribbon(project * p1, color_mode * p9, i32s p2, i32s order) :
 		
 		if (error)
 		{
-			cout << "ribbon : failed to use susf." << endl;
-			exit(EXIT_FAILURE);
+			assertion_failed(__FILE__, __LINE__, "susf error.");
 		}
 		
 		for (i32u n1 = 0;n1 < susf->chn_vector[chn].res_vector.size();n1++)
@@ -159,13 +156,22 @@ ogl_ribbon::ogl_ribbon(project * p1, color_mode * p9, i32s p2, i32s order) :
 		iter_al range2b[2]; prj->GetRange(2, range1, n1 + 1, range2b);
 		
 		c_alpha_2 = range2b[0]; while (c_alpha_2 != range2b[1] && ((* c_alpha_2).builder_res_id & 0xFF) != 0x01) c_alpha_2++;
-		if (c_alpha_2 == range2b[1]) { cout << "ERROR : search of C_alpha 2 failed." << endl; exit(EXIT_FAILURE); }
+		if (c_alpha_2 == range2b[1])
+		{
+			assertion_failed(__FILE__, __LINE__, "C_alpha_2 not found.");
+		}
 		
 		c_alpha_1 = range2a[0]; while (c_alpha_1 != range2a[1] && ((* c_alpha_1).builder_res_id & 0xFF) != 0x01) c_alpha_1++;
-		if (c_alpha_1 == range2a[1]) { cout << "ERROR : search of C_alpha 1 failed." << endl; exit(EXIT_FAILURE); }
+		if (c_alpha_1 == range2a[1])
+		{
+			assertion_failed(__FILE__, __LINE__, "C_alpha_1 not found.");
+		}
 		
 		iter_al c_carboxyl = range2a[0]; while (c_carboxyl != range2a[1] && ((* c_carboxyl).builder_res_id & 0xFF) != 0x02) c_carboxyl++;
-		if (c_carboxyl == range2a[1]) { cout << "ERROR : search of c_carboxyl failed." << endl; exit(EXIT_FAILURE); }
+		if (c_carboxyl == range2a[1])
+		{
+			assertion_failed(__FILE__, __LINE__, "C_carboxyl not found.");
+		}
 		
 		ca_to_ca = v3d<fGL>((* c_alpha_1).GetCRD(0), (* c_alpha_2).GetCRD(0));
 		v3d<fGL> tmpv1 = v3d<fGL>((* c_alpha_1).GetCRD(0), (* c_carboxyl).GetCRD(0));
@@ -247,7 +253,9 @@ ogl_ribbon::ogl_ribbon(project * p1, color_mode * p9, i32s p2, i32s order) :
 		ref2->SetKnot(n1, (fGL) (n1 - extra_points) - (fGL) order / 2.0);
 	}
 	
+#ifdef RIBBON_USE_DISPLSTS
 	list_id = prj->GetDisplayListIDs(1);
+#endif	// RIBBON_USE_DISPLSTS
 	
 	i32s np1 = resol * (length - 1);
 	i32s np2 = np1 + 1;
@@ -306,7 +314,9 @@ ogl_ribbon::~ogl_ribbon(void)
 	delete[] data2b;
 	delete[] data3;
 	
+#ifdef RIBBON_USE_DISPLSTS
 	prj->DeleteDisplayLists(list_id, 1);
+#endif	// RIBBON_USE_DISPLSTS
 }
 
 void ogl_ribbon::UpdateExtraPoints(fGL ** hr, fGL * hp, fGL ** tr, fGL * tp)
@@ -332,10 +342,12 @@ void ogl_ribbon::UpdateExtraPoints(fGL ** hr, fGL * hp, fGL ** tr, fGL * tp)
 
 void ogl_ribbon::Render(void)
 {
+#ifdef RIBBON_USE_DISPLSTS
 	if (glIsList(list_id) == GL_TRUE) glCallList(list_id);
 	else
 	{
 		glNewList(list_id, GL_COMPILE_AND_EXECUTE);
+#endif	// RIBBON_USE_DISPLSTS
 		
 		i32s np1 = resol * (length - 1);
 		
@@ -401,8 +413,10 @@ void ogl_ribbon::Render(void)
 		glLightModeli(GL_LIGHT_MODEL_TWO_SIDE, false);
 		glDisable(GL_LIGHTING);
 		
+#ifdef RIBBON_USE_DISPLSTS
 		glEndList();
 	}
+#endif	// RIBBON_USE_DISPLSTS
 }
 
 /*################################################################################################*/
