@@ -39,6 +39,9 @@ class spline;	 	// spline.h
 
 /*################################################################################################*/
 
+//#define RIBBON_USE_DISPLSTS	// un-comment this to enable use of OpenGL display lists...
+//^^^^^^^^^^^^^^^^^^^^^^^^^^^ 20090420 ; this seems to have problems : assertion `GTK_WIDGET_REALIZED (widget)' failed
+
 class ogl_ribbon :
 	public ogl_smart_object
 {
@@ -70,7 +73,9 @@ class ogl_ribbon :
 	fGL * data2b;		// coordinates calculated using the spline (three components)
 	fGL * data3;		// colors of the points (three components)
 	
+#ifdef RIBBON_USE_DISPLSTS
 	iGLu list_id;
+#endif	// RIBBON_USE_DISPLSTS
 	
 	static const i32s resol;
 	
