@@ -20,17 +20,19 @@
 
 #include "ogl_surface.h"	// config.h is here -> we get ENABLE-macros here...
 
-#include <cstring>	// required by gcc-4.3
-#include <deque>
-#include <sstream>
-using namespace std;
-
 #include <ghemical/v3d.h>
 #include <oglappth/base_app.h>
 
 #include "project.h"
 #include "appdefine.h"
 
+#include "local_i18n.h"
+
+#include <cstring>
+#include <deque>
+#include <sstream>
+using namespace std;
+
 /*################################################################################################*/
 
 ogl_color_surface::ogl_color_surface(ogl_cs_param & p1)
@@ -86,7 +88,7 @@ void ogl_color_surface::Update(void)
 	tdata.resize(0);
 	ldata.resize(0);
 	
-	prj->PrintToLog("evaluating grid");
+	prj->PrintToLog(_("evaluating grid"));
 	for (i32s n1 = 0;n1 < np[0];n1++)
 	{
 		prj->PrintToLog("*");	// slow to update???
@@ -101,13 +103,13 @@ void ogl_color_surface::Update(void)
 		}
 	}
 	
-	prj->PrintToLog(" done\n");
+	prj->PrintToLog(_(" done\n"));
 	
 	avrg = 0.0; acnt = 0;
 	for (i32s n1 = 0;n1 < 3;n1++)
 	{
 		i32s tmp1[2]; i32s tmp2[2] = { 0, 0 };
-		prj->PrintToLog("interpolating in ");
+		prj->PrintToLog(_("interpolating in "));
 		switch (n1)
 		{
 			case 0:
@@ -126,14 +128,14 @@ void ogl_color_surface::Update(void)
 			break;
 		}
 		
-		prj->PrintToLog("-direction... ");
+		prj->PrintToLog(_("-direction... "));
 		
 		range[n1][0] = vdata.size();
 		Interpolate(n1, tmp1, tmp2);
 		range[n1][1] = vdata.size();
 		
 		ostringstream str1;
-		str1 << tmp2[0] << " points, " << tmp2[1] << " cycles" << endl << ends;
+		str1 << tmp2[0] << _(" points, ") << tmp2[1] << _(" cycles") << endl << ends;
 		prj->PrintToLog(str1.str().c_str());
 	}
 	
@@ -150,7 +152,7 @@ void ogl_color_surface::Update(void)
 		GetColor((vdata[n1].cvalue + cvalue2) / cvalue1, alpha, vdata[n1].color);
 	}
 	
-	prj->PrintToLog("generating image... ");
+	prj->PrintToLog(_("generating image... "));
 	
 	for (i32s n1 = 0;n1 < np[0] - 1;n1++)
 	{
@@ -180,7 +182,7 @@ void ogl_color_surface::Update(void)
 								{
 					i32s tmp1 = min(id1[0], id1[n7 + 1]); id2[n7] = range[n7][0];
 					while (id2[n7] < range[n7][1] && vdata[id2[n7]].id != tmp1) id2[n7]++;
-					if (id2[n7] == range[n7][1]) cout << "color_surface problem #1" << endl;
+					if (id2[n7] == range[n7][1]) cout << _("color_surface problem #1") << endl;
 								}
 							}
 							
@@ -230,7 +232,7 @@ void ogl_color_surface::Update(void)
 						if (grid[id1a[n5]] != grid[id1b[n5]])
 						{
 			id2[n5] = range[n4][0]; while (id2[n5] < range[n4][1] && vdata[id2[n5]].id != id1a[n5]) id2[n5]++;
-			if (id2[n5] == range[n4][1]) cout << "color_surface problem #2" << endl;
+			if (id2[n5] == range[n4][1]) cout << _("color_surface problem #2") << endl;
 						}
 					}
 					
@@ -330,7 +332,7 @@ void ogl_color_surface::Update(void)
 	}
 	
 	ostringstream str1;
-	str1 << ldata.size() << " lines, " << tdata.size() << " triangles." << endl << ends;
+	str1 << ldata.size() << _(" lines, ") << tdata.size() << _(" triangles.") << endl << ends;
 	prj->PrintToLog(str1.str().c_str());
 	
 	// add/update the primitives, if this is a transparent object...
