@@ -755,7 +755,7 @@ void oglview_wcl::UpdateWnd(void)
 		w->SetCurrent();
 		MyUpdateWnd();
 	}
-	else cout << "oglview_wcl::UpdateWnd() : skipped!" << endl;
+	else cout << "DEBUG : oglview_wcl::UpdateWnd() : skipped!" << endl;
 }
 
 void oglview_wcl::MyUpdateWnd(pmode pm, int x, int y)
