@@ -23,7 +23,7 @@
 //#include "project.h"
 #include "custom_app.h"
 
-#include <cstring>	// required by gcc-4.3
+#include <cstring>
 #include <sstream>
 using namespace std;
 
@@ -45,10 +45,10 @@ p1dview_wcl::p1dview_wcl(const char * s1, const char * sv) :
 //cout << "cam crd = " << d->crd[0] << " " << d->crd[1] << " " << d->crd[2] << endl;
 //cout << "cam zdir = { " << d->zdir << " }" << endl << "cam ydir = { " << d->ydir << " }" << endl;
 	
-	if (!s1 || !strlen(s1)) { cout << "invalid s1 passed to plot1d_view!" << endl; exit(EXIT_FAILURE); }
+	if (!s1 || !strlen(s1)) assertion_failed(__FILE__, __LINE__, "invalid s1.");
 	else { name1 = new char[strlen(s1) + 1]; strcpy(name1, s1); }
 	
-	if (!sv || !strlen(sv)) { cout << "invalid sv passed to plot1d_view!" << endl; exit(EXIT_FAILURE); }
+	if (!sv || !strlen(sv)) assertion_failed(__FILE__, __LINE__, "invalid sv.");
 	else { namev = new char[strlen(sv) + 1]; strcpy(namev, sv); }
 }
 
