@@ -25,7 +25,9 @@
 
 #include "color.h"
 
-#include <cstring>	// required by gcc-4.3
+#include "local_i18n.h"
+
+#include <cstring>
 #include <sstream>
 using namespace std;
 
@@ -47,13 +49,13 @@ p2dview_wcl::p2dview_wcl(const char * s1, const char * s2, const char * sv) :
 //cout << "cam crd = " << d->crd[0] << " " << d->crd[1] << " " << d->crd[2] << endl;
 //cout << "cam zdir = { " << d->zdir << " }" << endl << "cam ydir = { " << d->ydir << " }" << endl;
 	
-	if (!s1 || !strlen(s1)) { cout << "invalid s1 passed to plot2d_view!" << endl; exit(EXIT_FAILURE); }
+	if (!s1 || !strlen(s1)) assertion_failed(__FILE__, __LINE__, "invalid s1.");
 	else { name1 = new char[strlen(s1) + 1]; strcpy(name1, s1); }
 	
-	if (!s2 || !strlen(s2)) { cout << "invalid s2 passed to plot2d_view!" << endl; exit(EXIT_FAILURE); }
+	if (!s2 || !strlen(s2)) assertion_failed(__FILE__, __LINE__, "invalid s2.");
 	else { name2 = new char[strlen(s2) + 1]; strcpy(name2, s2); }
 	
-	if (!sv || !strlen(sv)) { cout << "invalid sv passed to plot2d_view!" << endl; exit(EXIT_FAILURE); }
+	if (!sv || !strlen(sv)) assertion_failed(__FILE__, __LINE__, "invalid sv.");
 	else { namev = new char[strlen(sv) + 1]; strcpy(namev, sv); }
 }
 
@@ -177,7 +179,7 @@ void p2dview_wcl::MotionEvent(int x, int y)
 		maxv += mouseinfo::dist_sensitivity * scale * (fGL) dy / (fGL) wnd->GetHeight();
 		
 		ostringstream str1;
-		str1 << "now scaling the colours to range " << (maxv - minv) << " kJ/mol" << endl << ends;
+		str1 << _("now scaling the colours to range ") << (maxv - minv) << _(" kJ/mol") << endl << ends;
 		prj->PrintToLog(str1.str().c_str());
 		
 		wnd->RequestUpdate(false);
