@@ -2,8 +2,19 @@
 
 // Copyright (C) 1998 Tommi Hassinen.
 
-// This program is free software; you can redistribute it and/or modify it
-// under the terms of the license (GNU GPL) which comes with this package.
+// This package is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation; either version 2 of the License, or
+// (at your option) any later version.
+
+// This package is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License
+// along with this package; if not, write to the Free Software
+// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 
 /*################################################################################################*/
 
@@ -58,8 +69,13 @@ class jobinfo_GeomOpt
 	
 	project * prj;
 	geomopt_param go;	// this is a class...
+	bool show_dialog;
 	
-	jobinfo_GeomOpt(void) : go(NULL) { prj = NULL; }
+	jobinfo_GeomOpt(void) : go(NULL)
+	{
+		prj = NULL;
+		show_dialog = false;
+	}
 };
 
 class jobinfo_MolDyn
@@ -68,8 +84,13 @@ class jobinfo_MolDyn
 	
 	project * prj;
 	moldyn_param md;	// this is a class...
+	bool show_dialog;
 	
-	jobinfo_MolDyn(void) : md(NULL) { prj = NULL; }
+	jobinfo_MolDyn(void) : md(NULL)
+	{
+		prj = NULL;
+		show_dialog = false;
+	}
 };
 
 struct jobinfo_RandomSearch
@@ -141,7 +162,18 @@ class project :
 	static ogl_dummy_object * selected_object;
 	
 	static const char appversion[16];
-	static const char appdata_path[256];
+	static char appdata_path[256];		// also see libghemical_init()...
+
+/**	If background_job_running is "true" it means that a geometry optimization,
+	molecular dynamics etc. job is running on the background, and the user possibly
+	can access any of the GUI elements. What we want is to block user out from any
+	GUI elements that might be able directly or indirectly modify any internal state
+	or information of the model object (for example addition or removal of atoms or
+	bonds will instantly mess up everything ; sorting atoms/bonds does the same ;
+	etc...). However it is good if user can update graphics using zoom/turning tools
+	and so on...
+*/
+	static bool background_job_running;
 	
 	static color_mode_element cm_element;
 	static color_mode_secstruct cm_secstruct;
@@ -219,13 +251,9 @@ class project :
 // we need to intercept these atom/bond events from the
 // model class in order to keep "project view" up-to-date!
 	
-	void AddAtom(atom &);		// virtual
+	void AddAtom_lg(atom &);	// virtual
 	void RemoveAtom(iter_al);	// virtual
 	
-#ifdef WIN32
-void w32_check_for_skipped_AddAtom_calls(atom *);	// static???
-#endif	// WIN32
-	
 	void AddBond(bond &);		// virtual
 	void RemoveBond(iter_bl);	// virtual
 	
@@ -312,13 +340,9 @@ void MeasureEvent(oglview_wcl *, vector<iGLu> &);
 	// some common operations are implemented here:
 	// ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
 	
-#ifdef ENABLE_THREADS
-
 	virtual void CreateProgressDialog(const char *, bool, int, int) = 0;
 	virtual void DestroyProgressDialog(void) = 0;
 	
-#endif	// ENABLE_THREADS
-	
 	void ProcessCommandString(oglview_wcl *, const char *);
 	
 	virtual void start_job_GeomOpt(jobinfo_GeomOpt *) = 0;
@@ -365,13 +389,9 @@ class dummy_project : public project
 	dummy_project(void);
 	~dummy_project(void);
 	
-#ifdef ENABLE_THREADS
-	
 	void CreateProgressDialog(const char *, bool, int, int) { }
 	void DestroyProgressDialog(void) { }
 	
-#endif	// ENABLE_THREADS
-	
 	void start_job_GeomOpt(jobinfo_GeomOpt *) { }
 	void start_job_MolDyn(jobinfo_MolDyn *) { }
 	void start_job_RandomSearch(jobinfo_RandomSearch *) { }
