@@ -20,10 +20,12 @@
 
 #include "rcpview_wcl.h"
 
-//#include "project.h"
 #include "custom_app.h"
 
+#include "local_i18n.h"
+
 #include <sstream>
+using namespace std;
 
 /*################################################################################################*/
 
@@ -156,7 +158,7 @@ void rcpview_wcl::Finalize(void)
 	project * prj = custom_app::GetAppC()->GetPrj();
 	
 	ostringstream txts;
-	txts << "the tresholds were set to " << r_treshold << " and " << p_treshold << endl << ends;
+	txts << _("the tresholds were set to ") << r_treshold << _(" and ") << p_treshold << endl << ends;
 	prj->PrintToLog(txts.str().c_str());
 	
 	ready = true;
